#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor gtk3%nil

%define _name webkitgtk
%if "%{flavor}" == ""
# gtknamesuffix is just so we do not have to rename the source package - no package is generated here
%define _gtknamesuffix gtk3
ExclusiveArch:  do-not-build
%endif

%define usegcc11 0%{?sle_version} && 0%{?sle_version} <= 150400

%if "%{flavor}" == "gtk3"
%define _gtknamesuffix gtk3
%define _pkgname_no_slpp libwebkit2gtk3
%define _apiver 4.1
%define _sover -4_1-0
%define _wk2sover -4_1-0
%define _sonamever 4.1
%define _sonameverpkg 4_1
%define _gtkver 3.0
%define _jscver 4.1
%define _pkgconfig_suffix gtk-3.0
%define _usesoup2 0
%endif

%if "%{flavor}" == "gtk3-soup2"
%define _gtknamesuffix gtk3-soup2
%define _pkgname_no_slpp libwebkit2gtk3
%define _apiver 4.0
%define _sover -4_0-18
%define _wk2sover -4_0-37
%define _sonamever 4.0
%define _sonameverpkg 4_0
%define _gtkver 3.0
%define _jscver 4
%define _pkgconfig_suffix gtk-3.0
%define _usesoup2 1
%endif

%if "%{flavor}" == "gtk4"
%define _gtknamesuffix gtk4
%define _pkgname_no_slpp libwebkit2gtk4
%define _apiver 6.0
%define _sover -6_0-0
%define _wk2sover -6_0-0
%define _sonamever 6.0
%define _sonameverpkg 6_0
%define _gtkver 4.0
%define _jscver 6.0
%define _pkgconfig_suffix gtk-4.0
%define _usesoup2 0
%define _wk2sover6api -6_0-4
%define _soverlj6api -6_0-1
%endif

# gold linker not available on old s390/s390x
%define _gold_linker 0
%ifarch ppc ppc64le s390
%define _gold_linker 0
%endif
Name:           webkit2%{_gtknamesuffix}
Version:        2.42.3
Release:        150400.4.67.1
Summary:        Library for rendering web content, GTK+ Port
License:        BSD-3-Clause AND LGPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://webkitgtk.org
Source0:        %{url}/releases/%{_name}-%{version}.tar.xz
Source1:        %{url}/releases/%{_name}-%{version}.tar.xz.asc
Source98:       baselibs.conf
Source99:       webkit2gtk3.keyring

# PATCH-FIX-UPSTREAM webkit2gtk3-gtk4-build-fix.patch mgorse@suse.com -- fix the build with gtk 4.6.0
Patch1:         webkit2gtk3-gtk4-build-fix.patch
# PATCH-FIX-UPSTREAM webkit2gtk3-create-destroy-egl-image.patch boo#1216483 mgorse@suse.com -- fix "No providef of EglDestroyImage found".
Patch2:         webkit2gtk3-create-destroy-egl-image.patch
# PATCH-FIX-UPSTREAM webkit2gtk3-disable-dmabuf-nvidia.patch boo#1216778 mgorse@suse.com -- disable the DMABuf renderer for NVIDIA proprietary drivers.
Patch3:         webkit2gtk3-disable-dmabuf-nvidia.patch
# PATCH-FIX-UPSTREAM webkit2gtk3-gstreamer-build-fix.patch mgorse@suse.com -- fix the build with !ENABLE(MEDIA_STREAM).
Patch4:         webkit2gtk3-gstreamer-build-fix.patch

BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGL-devel
BuildRequires:  Mesa-libGLESv1_CM-devel
BuildRequires:  Mesa-libGLESv2-devel
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  bison >= 2.3
BuildRequires:  bubblewrap
BuildRequires:  cmake
BuildRequires:  enchant-devel
BuildRequires:  flex
%if %usegcc11
BuildRequires:  gcc11-c++
%else
BuildRequires:  gcc-c++ >= 8.3
%endif
BuildRequires:  gobject-introspection-devel
BuildRequires:  gperf >= 3.0.1
BuildRequires:  hyphen-devel
BuildRequires:  libicu-devel
BuildRequires:  libjpeg-devel
BuildRequires:  ninja
BuildRequires:  openjpeg2
BuildRequires:  openjpeg2-devel
BuildRequires:  perl >= 5.10.0
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  ruby >= 1.9
%if %{_gold_linker}
BuildRequires:  binutils-gold
%endif
BuildRequires:  unifdef
BuildRequires:  xdg-dbus-proxy
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(atspi-2) >= 2.5.3
BuildRequires:  pkgconfig(cairo) >= 1.14.0
BuildRequires:  pkgconfig(fontconfig) >= 2.8.0
BuildRequires:  pkgconfig(freetype2) >= 2.4.2
BuildRequires:  pkgconfig(glib-2.0) >= 2.56.4
%if %usegcc11
BuildRequires:  pkgconfig(glproto)
%endif
BuildRequires:  pkgconfig(gnutls) >= 3.0.0
BuildRequires:  pkgconfig(gstreamer-1.0) >= 1.14.0
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-codecparsers-1.0)
BuildRequires:  pkgconfig(gstreamer-fft-1.0)
BuildRequires:  pkgconfig(gstreamer-gl-1.0)
BuildRequires:  pkgconfig(gstreamer-mpegts-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
%if "%{flavor}" == "gtk3" || "%{flavor}" == "gtk3-soup2"
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
%endif
%if "%{flavor}" == "gtk4"
BuildRequires:  pkgconfig(gtk4) >= 3.98.50
BuildRequires:  pkgconfig(xcomposite)
%endif
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(harfbuzz) >= 0.9.18
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libavif) >= 0.9.0
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libseccomp)
BuildRequires:  pkgconfig(libsecret-1)
%if %{_usesoup2}
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.54.0
%else
BuildRequires:  pkgconfig(libsoup-3.0) >= 3.0.0
%endif
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libwoff2dec)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.8.0
BuildRequires:  pkgconfig(libxslt) >= 1.1.7
BuildRequires:  pkgconfig(manette-0.2)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(upower-glib)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wpe-1.0) >= 1.3.0
BuildRequires:  pkgconfig(wpebackend-fdo-1.0) >= 1.6.0
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)

%description
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

%package -n libwebkit2gtk%{_wk2sover}
Summary:        Library for rendering web content, GTK+ Port
# Require the injected bundles. The bundles are dlopen()ed
Group:          System/Libraries
Requires:       bubblewrap
%if "%{flavor}" == "gtk4"
Requires:       libjavascriptcoregtk%{_soverlj6api} = %{version}
%else
Requires:       libjavascriptcoregtk%{_sover} = %{version}
%endif
Requires:  libwayland-client0 >= 1.20.0
Requires:       webkit2gtk-%{_sonameverpkg}-injected-bundles
Requires:       xdg-dbus-proxy
Provides:       %{_pkgname_no_slpp} = %{version}
Provides:       WebKitGTK-%{_apiver}
Obsoletes:      webkit2gtk3-plugin-process-gtk2 < %{version}
Recommends:     geoclue2
Recommends:     gstreamer-plugins-bad
Recommends:     gstreamer-plugins-good
Recommends:     xdg-desktop-portal-gtk

%description -n libwebkit2gtk%{_wk2sover}
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

%package -n libwebkitgtk%{_wk2sover6api}
Summary:        Library for rendering web content, GTK+ Port
# Require the injected bundles. The bundles are dlopen()ed
Group:          System/Libraries
Requires:       bubblewrap
%if "%{flavor}" == "gtk4"
Requires:       libjavascriptcoregtk%{_soverlj6api} = %{version}
Requires:       webkitgtk-%{_sonameverpkg}-injected-bundles
%else
Requires:       libjavascriptcoregtk%{_sover} = %{version}
Requires:       webkit2gtk-%{_sonameverpkg}-injected-bundles
%endif
Requires:       xdg-dbus-proxy
Provides:       %{_pkgname_no_slpp} = %{version}
Provides:       WebKitGTK-%{_apiver}
Obsoletes:      webkit2gtk3-plugin-process-gtk2 < %{version}
Recommends:     geoclue2
Recommends:     gstreamer-plugins-bad
Recommends:     gstreamer-plugins-good
Recommends:     xdg-desktop-portal-gtk

%description -n libwebkitgtk%{_wk2sover6api}
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

%package -n webkitgtk-%{_sonameverpkg}-injected-bundles
Summary:        Injected bundles for %{name}
Group:          System/Libraries

%description -n webkitgtk-%{_sonameverpkg}-injected-bundles
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

%package -n webkit2gtk-%{_sonameverpkg}-injected-bundles
Summary:        Injected bundles for %{name}
Group:          System/Libraries

%description -n webkit2gtk-%{_sonameverpkg}-injected-bundles
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

%package -n libjavascriptcoregtk%{_sover}
Summary:        JavaScript Core Engine, GTK+ Port
Group:          System/Libraries

%description -n libjavascriptcoregtk%{_sover}
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

%package -n libjavascriptcoregtk%{_soverlj6api}
Summary:        JavaScript Core Engine, GTK+ Port
Group:          System/Libraries

%description -n libjavascriptcoregtk%{_soverlj6api}
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

%package -n typelib-1_0-WebKit-%{_sonameverpkg}
Summary:        Introspection bindings for %{name}
Group:          System/Libraries

%description -n typelib-1_0-WebKit-%{_sonameverpkg}
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

This package provides the GObject Introspection bindings for the GTK+
port of WebKit2.

%package -n typelib-1_0-WebKitWebProcessExtension-%{_sonameverpkg}
Summary:        Introspection bindings for %{name}
Group:          System/Libraries

%description -n typelib-1_0-WebKitWebProcessExtension-%{_sonameverpkg}
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

This package provides the GObject Introspection bindings for the GTK+
port of WebKit2.

%package -n typelib-1_0-WebKit2-%{_sonameverpkg}
Summary:        Introspection bindings for %{name}
Group:          System/Libraries

%description -n typelib-1_0-WebKit2-%{_sonameverpkg}
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

This package provides the GObject Introspection bindings for the GTK+
port of WebKit2.

%package -n typelib-1_0-WebKit2WebExtension-%{_sonameverpkg}
Summary:        Introspection bindings for %{name}
Group:          System/Libraries

%description -n typelib-1_0-WebKit2WebExtension-%{_sonameverpkg}
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

This package provides the GObject Introspection bindings for the GTK+
port of WebKit2.

%package -n typelib-1_0-JavaScriptCore-%{_sonameverpkg}
Summary:        Introspection bindings for the GTK+ port of the JavaScript Core Engine
Group:          System/Libraries

%description -n typelib-1_0-JavaScriptCore-%{_sonameverpkg}
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

This package provides the GObject Introspection bindings for the GTK+
port of the JavaScript Core engine.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
%if "%{flavor}" == "gtk4"
Requires:       libjavascriptcoregtk%{_soverlj6api} = %{version}
Requires:       libwebkitgtk%{_wk2sover6api} = %{version}
Requires:       typelib-1_0-JavaScriptCore-%{_sonameverpkg}
Requires:       typelib-1_0-WebKit-%{_sonameverpkg}
Requires:       typelib-1_0-WebKitWebProcessExtension-%{_sonameverpkg}
%else
Requires:       libjavascriptcoregtk%{_sover} = %{version}
Requires:       libwebkit2gtk%{_wk2sover} = %{version}
Requires:       typelib-1_0-JavaScriptCore-%{_sonameverpkg}
Requires:       typelib-1_0-WebKit2-%{_sonameverpkg}
Requires:       typelib-1_0-WebKit2WebExtension-%{_sonameverpkg}
%endif

%description devel
WebKit is a web content engine, derived from KHTML and KJS from KDE,
and used primarily in Apple's Safari browser.  It is made to be
embedded in other applications, such as mail readers, or web browsers.

It is able to display content such as HTML, SVG, XML, and others. It
also supports DOM, XMLHttpRequest, XSLT, CSS, Javascript/ECMAscript and
more.

%package -n webkit-jsc-%{_jscver}
Summary:        JavaScript command line from WebKit
Group:          Development/Tools/Other

%description -n webkit-jsc-%{_jscver}
jsc is a command-line utility that allows you to run JavaScript
programs outside of the context of a web browser. It is primarily
used as part of the test harness for validating the JavaScript
portions of WebKit, but can also be used as a scripting tool.

jsc can be run in an interactive mode to test out JavaScript
expressions, or it can be passed one or more files to run similar to
invoking a Perl or Python script.

%package minibrowser
Summary:        MiniBrowser from WebKit
Group:          Development/Tools/Other

%description minibrowser
A small test browswer from webkit, useful for testing features.

# Expand %%lang_package to Obsoletes its older-name counterpart
%package -n WebKitGTK-%{_apiver}-lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       WebKitGTK-%{_apiver} = %{version}
Provides:       WebKitGTK-%{_apiver}-lang-all = %{version}
Obsoletes:      libwebkit2gtk3-lang < %{version}
Provides:       libwebkit2gtk3-lang < %{version}
Provides: WebKit2GTK-%{_apiver}-lang = %version
Obsoletes: WebKit2GTK-%{_apiver}-lang < %version
BuildArch:      noarch

%description -n WebKitGTK-%{_apiver}-lang
Provides translations for the "%{name}" package.

%prep
%autosetup -p1 -n webkitgtk-%{version}

%build
# Here we must muzzle our dog so it doesn't eat all the memory
max_link_jobs="%{?jobs:%{jobs}}"
max_compile_jobs="%{?jobs:%{jobs}}"
echo "Available memory:"
cat /proc/meminfo
echo "System limits:"
ulimit -a
if test -n "$max_link_jobs" -a "$max_link_jobs" -gt 1 ; then
        mem_per_process=2000000
    max_mem=$(awk '/MemTotal/ { print $2 }' /proc/meminfo)
    max_jobs="$(($max_mem / $mem_per_process))"
    test "$max_link_jobs" -gt "$max_jobs" && max_link_jobs="$max_jobs" && echo "Warning: Reducing number of link jobs to $max_jobs because of memory limits"
    test "$max_link_jobs" -le 0 && max_link_jobs=1 && echo "Warning: Not linking in parallel at all becuse of memory limits"
fi

export PYTHON=%{_bindir}/python3
# Use linker flags to reduce memory consumption
%if %{_gold_linker}
%global optflags %(echo %{optflags} -Wl,--no-keep-memory | sed 's/-g /-g1 /')
%else
%global optflags %(echo %{optflags} -Wl,--no-keep-memory -Wl,--reduce-memory-overheads | sed 's/-g /-g1 /')
%endif
%cmake \
  -GNinja \
  -DCMAKE_BUILD_TYPE=Release \
  -DENABLE_DOCUMENTATION=OFF \
%if %usegcc11
  -DCMAKE_C_COMPILER=gcc-11 \
  -DCMAKE_CXX_COMPILER=g++-11 \
%endif
  -DPORT=GTK \
%if "%{flavor}" == "gtk4"
  -DLIBEXEC_INSTALL_DIR=%{_libexecdir}/libwebkitgtk%{_wk2sover} \
  -DUSE_GTK4=ON \
  -DENABLE_WEBDRIVER=ON \
%else
  -DLIBEXEC_INSTALL_DIR=%{_libexecdir}/libwebkit2gtk%{_wk2sover} \
  -DENABLE_WEBDRIVER=OFF \
%endif
  -DUSE_AVIF=ON \
  -DUSE_JPEGXL=OFF \
  -DENABLE_MEDIA_STREAM=OFF \
  -DENABLE_MINIBROWSER=ON \
  -DCMAKE_EXE_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now -pthread" \
  -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now -pthread" \
  -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now -pthread" \
  -DPYTHON_EXECUTABLE=%{_bindir}/python3 \
%if %{_usesoup2}
  -DUSE_SOUP2=ON \
%endif
  -DUSE_SYSTEM_MALLOC=ON \
%ifarch aarch64
  -DENABLE_JIT=OFF \
  -DENABLE_C_LOOP=ON \
  -DENABLE_SAMPLING_PROFILER=OFF \
  -DUSE_SYSTEM_MALLOC=ON \
%endif

%ninja_build -j $max_link_jobs

%install
%ninja_install -C build
%find_lang WebKitGTK-%{_apiver}

%if "%{flavor}" == "gtk4"
%ldconfig_scriptlets -n libwebkitgtk%{_wk2sover6api}
%ldconfig_scriptlets -n libjavascriptcoregtk%{_soverlj6api}
%else
%ldconfig_scriptlets -n libwebkit2gtk%{_wk2sover}
%ldconfig_scriptlets -n libjavascriptcoregtk%{_sover}
%endif

%if "%{flavor}" == "gtk4"
%files -n libwebkitgtk%{_wk2sover6api}
# Exclude jsc and MiniBrowser - we package them on their own
%exclude %{_libexecdir}/libwebkitgtk%{_wk2sover}/jsc
%exclude %{_libexecdir}/libwebkitgtk%{_wk2sover}/MiniBrowser
%{_libexecdir}/libwebkitgtk%{_wk2sover}/
%{_libdir}/libwebkitgtk-%{_apiver}.so.*

%files -n webkitgtk-%{_sonameverpkg}-injected-bundles
%dir %{_libdir}/webkitgtk-%{_apiver}
%dir %{_libdir}/webkitgtk-%{_apiver}/injected-bundle
%{_libdir}/webkitgtk-%{_apiver}/injected-bundle/libwebkitgtkinjectedbundle.so

%else

%files -n libwebkit2gtk%{_wk2sover}
# Exclude jsc and MiniBrowser - we package them on their own
%exclude %{_libexecdir}/libwebkit2gtk%{_wk2sover}/jsc
%exclude %{_libexecdir}/libwebkit2gtk%{_wk2sover}/MiniBrowser
%{_libexecdir}/libwebkit2gtk%{_wk2sover}/
%{_libdir}/libwebkit2gtk-%{_apiver}.so.*

%files -n webkit2gtk-%{_sonameverpkg}-injected-bundles
%dir %{_libdir}/webkit2gtk-%{_apiver}
%dir %{_libdir}/webkit2gtk-%{_apiver}/injected-bundle
%{_libdir}/webkit2gtk-%{_apiver}/injected-bundle/libwebkit2gtkinjectedbundle.so

%endif

%if "%{flavor}" == "gtk4"

%files -n libjavascriptcoregtk%{_soverlj6api}
%license Source/JavaScriptCore/COPYING.LIB
%{_libdir}/libjavascriptcoregtk-%{_apiver}.so.*

%files -n typelib-1_0-WebKit-%{_sonameverpkg}
%{_libdir}/girepository-1.0/WebKit-%{_sonamever}.typelib

%files -n typelib-1_0-WebKitWebProcessExtension-%{_sonameverpkg}
%{_libdir}/girepository-1.0/WebKitWebProcessExtension-%{_sonamever}.typelib

%else

%files -n libjavascriptcoregtk%{_sover}
%license Source/JavaScriptCore/COPYING.LIB
%{_libdir}/libjavascriptcoregtk-%{_apiver}.so.*

%files -n typelib-1_0-WebKit2-%{_sonameverpkg}
%{_libdir}/girepository-1.0/WebKit2-%{_sonamever}.typelib

%files -n typelib-1_0-WebKit2WebExtension-%{_sonameverpkg}
%{_libdir}/girepository-1.0/WebKit2WebExtension-%{_sonamever}.typelib

%endif

%files -n typelib-1_0-JavaScriptCore-%{_sonameverpkg}
%{_libdir}/girepository-1.0/JavaScriptCore-%{_sonamever}.typelib

%files devel
%{_datadir}/gir-1.0/*.gir
%{_includedir}/webkitgtk-%{_apiver}/
%if "%{flavor}" == "gtk4"
%{_libdir}/libwebkitgtk-%{_sonamever}.so
%{_libdir}/pkgconfig/webkitgtk-%{_apiver}.pc
%{_libdir}/pkgconfig/webkitgtk-web-process-extension-%{_apiver}.pc
%else
%{_libdir}/libwebkit2gtk-%{_sonamever}.so
%{_libdir}/pkgconfig/webkit2gtk-%{_apiver}.pc
%{_libdir}/pkgconfig/webkit2gtk-web-extension-%{_apiver}.pc
%endif
%{_libdir}/libjavascriptcoregtk-%{_sonamever}.so
%{_libdir}/pkgconfig/javascriptcoregtk-%{_apiver}.pc

%files -n webkit-jsc-%{_jscver}
%if "%{flavor}" == "gtk4"
%{_libexecdir}/libwebkitgtk%{_wk2sover}/jsc
%else
%{_libexecdir}/libwebkit2gtk%{_wk2sover}/jsc
%endif

%files minibrowser
%if "%{flavor}" == "gtk4"
%{_libexecdir}/libwebkitgtk%{_wk2sover}/MiniBrowser
%{_bindir}/WebKitWebDriver
%else
%{_libexecdir}/libwebkit2gtk%{_wk2sover}/MiniBrowser
%endif

%files -n WebKitGTK-%{_apiver}-lang -f WebKitGTK-%{_apiver}.lang

%changelog
* Wed Dec  6 2023 mgorse@suse.com
- Update to version 2.42.3 (boo#1217844):
  + Fix flickering while playing videos with DMA-BUF sink.
  + Fix color picker being triggered in the inspector when typing
    "tan".
  + Do not special case the "sans" font family name.
  + Fix build failure with libxml2 version 2.12.0 due to an API
    change.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2023-42916, CVE-2023-42917.
* Fri Nov 17 2023 mgorse@suse.com
- Update to version 2.42.2 (boo#1217210):
  + Bump Safari version in user agent header.
  + Fix CSP regression that broke Unity WebGL applications.
  + Fix the build with GBM disabled.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2023-41983, CVE-2023-42852.
- Add webkit2gtk3-gstreamer-build-fix.patch: fix the build with
  !ENABLE(MEDIA_STREAM).
* Wed Nov  1 2023 mgorse@suse.com
- Add webkit2gtk3-disable-dmabuf-nvidia.patch: disable DMABuf
  renderer for NVIDIA proprietary drivers (boo#1216778).
* Mon Oct 23 2023 mgorse@suse.com
- Add webkit2gtk3-create-destroy-egl-image.patch: fix "No provider
  of EglDestroyImage Found" (boo#1216483).
* Mon Oct  9 2023 mgorse@suse.com
- Update to version 2.42.1 (boo#1215661 boo#1215866 boo#1215867
  boo#1215868 boo#1215869 boo#1215870):
  + Fix enable-html5-database setting to properly enable/disable
    IndexedDB API.
  + Fix the build with GBM disabled.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2023-41993.
  + Changes in version 2.42.0:
  + New renderer based on DMA-BUF shared buffers.
  + Add new permission request to handle DOM paste access requests.
  + Add API to configure experimental features at runtime.
  + Add API to set the percentage of volume space that can be used
    for data storage.
  + GBM is no longer required for WebGL implementation.
  + Security fixes: CVE-2023-39928, CVE-2023-41074, CVE-2023-32359.
- Disable JPEGXL.
* Mon Sep 11 2023 mgorse@suse.com
- Expand lang sub-package in spec file unconditionally to handle
  previous name change from WebKit2GTK-lang to WebKitGTK-lang. This
  change affected the automatic generated Requires tag on
  WebKit2GTK-%%{_apiver}, then getting out of sync of what's being
  required and what's being provided. Now, any sub-package that was
  providing WebKit2GTK-%%{_apiver} will provide WebKitGTK-%%{_apiver}
  instead (boo#1214835, boo#1214640, boo#1214093).
- Require libwaylandclient0 >= 1.20. 15.4 originally had 1.19.0,
  but webkitgtk uses a function added in 1.20.0, so we need to
  ensure that the wayland update is pulled in (bsc#1215072).
* Mon Aug 28 2023 mgorse@suse.com
- Provide/obsolete WebKit2GTK-%%{_apiver}-lang (bsc#1214093)
* Fri Aug 11 2023 mgorse@suse.com
- Have the lang package provide libwebkit2gtk3-lang (bsc#1214093)
* Fri Aug  4 2023 mgorse@suse.com
- Update to version 2.40.5 (boo#1213905 boo#1213379 boo#1213581
  boo#1215230):
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2023-38133, CVE-2023-38572, CVE-2023-38592,
    CVE-2023-38594, CVE-2023-38595, CVE-2023-38597,
    CVE-2023-38599,, CVE-2023-38600, CVE-2023-38611,
    CVE-2023-40397, CVE-2023-39434, CVE-2023-40451.
  + Changes in version 2.40.3 (boo#1212863):
  + Make memory pressure monitor honor memory.memsw.usage_in_bytes
    if exists.
  + Include key modifiers in wheel events.
  + Apply cookie blocking policy to WebSocket handshakes.
  + Remove accidental dependency on GLib 2.70.
  + Fix the build with BUBBLEWRAP_SANDBOX disabled.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2023-32439, CVE-2023-32435, CVE-2023-32393,
    CVE-2023-37450, CVE-2023-28198, CVE-2023-32370, CVE-2023-35074.
- Add unifdef BuildRequires: New dependency.
- Remove libbrotlidec from BuildRequires. No longer needed.
- Drop no-forced-sse.patch: Due to changes in the code, trying to
  build without SSE2 support fails even with this patch. We are
  forced to give up on this, SSE2 support is now mandatory for all
  build targets.
- Drop webkit2gtk3-CVE-2023-28204.patch and
  webkit2gtk3-CVE-2023-32373.patch: fixed upstream.
- Disable MEDIA_STREAM. It has been disabled until now, and it's
  better to minimize the amount of gstreamer code that we need to
- The gtk 4 api version is now 6.0. The previous 5.0 version was
  considered by upstream to be an unreleased work in progress and
  is not used by anything that we ship in SP4.
* Thu Jun  8 2023 mgorse@suse.com
- Add security patches (boo#1211846):
  + webkit2gtk3-CVE-2023-28204.patch (boo#1211659 CVE-2023-28204)
  + webkit2gtk3-CVE-2023-32373.patch (boo#1211658 CVE-2023-32373)
* Fri Apr 21 2023 mgorse@suse.com
- Update to version 2.38.6 (boo#1210295 boo#1210731):
  + Enable the Asynchronous Clipboard API to make certain pages
    work (e.g. GithHub started recently requiring it).
  + Support :has() CSS selectors in content filters.
  + Apply basic font properties as font variation settings.
  + The Bubblewrap sandbox no longer requires setting an
    application identifier via GApplication to operate correctly.
    Using GApplication is still recommended, but optional.
  + Improvements to the GStreamer multimedia playback, in
    particular around MSE, WebRTC, and seeking.
  + Fix the build with journald support enabled when using elogind
    instead of the systemd libraries.
  + Fix the build with Link-Time Optimization enabled (-flto=auto).
  + Fix context menus not working in the remote Web Inspector.
  + Fix usage of the remote Web Inspector over HTTP.
  + Fix debug logs not being emitted in release builds.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-0108, CVE-2023-28205, CVE-2022-32885,
    CVE-2023-27932, CVE-2023-27954.
* Thu Feb 16 2023 mgorse@suse.com
- Update to version 2.38.5 (boo#1208328):
  + Fix large memory allocation when uploading content.
  + Fix scrolling after a history navigation with PSON enabled.
  + Always update the active uri of WebKitFrame.
  + Fix the build on Ubuntu 20.04.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2023-23529.
- Add webkit2gtk3-gtk4-build-fix.patch: fix the build with gtk
  4.6.0.
* Tue Feb  7 2023 mgorse@suse.com
- Update to version 2.38.4 (boo#1207997):
  + Improve GStreamer multimedia playback across the board with
    improved codec selection logic, better handling of latency, and
    improving frame discard to avoid audio/video
    desynchronizationg, among other fixes.
  + Disable HLS media playback by default, which makes web sites
    use MSE instead. If needed WEBKIT_GST_ENABLE_HLS_SUPPORT=1 can
    be set in the environment to enable it back.
  + Disable threaded rendering in GTK4 builds by default, as it was
    causing crashes.
  + Fix MediaSession API not showing artwork images.
  + Fix MediaSession MPRIS usage when running inside a Flatpak
    sandbox.
  + Fix input element controls to correctly scale when applying a
    zoom factor different than the default.
  + Fix leakage of Web processes in certain situations.
  + Fix the injected bundle not being found when running inside a
    sandbox.
  + Fix the build with ENABLE_INTROSPECTION when cross-compiling.
  + FIx the build with ENABLE_WEBGL disabled.
  + Fix the build with GStreamer-based WebRTC enabled.
  + Fix the build with USE_GTK4 enabled.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2023-23517, CVE-2023-23518, CVE-2022-42826,
    CVE-2022-32919, CVE-2022-46705, CVE-2022-46725.
* Thu Dec 22 2022 mgorse@suse.com
- Update to version 2.38.3 (boo#1206474 boo#1206750):
  + Fix runtime critical warnings from media player.
  + Fix network process crash when fetching website data on
    ephemeral session.
  + Fix the build with Ruby 3.2.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-42852, CVE-2022-42856, CVE-2022-42867,
    CVE-2022-46692, CVE-2022-46698, CVE-2022-46699, CVE-2022-46700.
* Tue Nov  8 2022 mgorse@suse.com
- Update to version 2.38.2 (boo#1205120 boo#1205123 boo#1205124):
  + Fix scrolling issues in some sites having fixed background.
  + Fix prolonged buffering during progressive live playback.
  + Fix the build with accessibility disabled.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-42799, CVE-2022-42823, CVE-2022-42824.
- Update no-forced-sse.patch with quilt.
- Pass -DENABLE_DOCUMENTATION=OFF to configure, we did not build
  the API docs in the past, and I see no reason to start now.
- Drop pkgconfig(libnotify) BuildRequires: No longer needed, nor
  used if available.
- Pass -DUSE_SYSTEM_MALLOC=ON on all architectures, to work
  around webkit#243535.
* Tue Nov  8 2022 mgorse@suse.com
- Update to version 2.38.1:
  + Make xdg-dbus-proxy work if host session bus address is an
    abstract socket.
  + Use a single xdg-dbus-proxy process when sandbox is enabled.
  + Fix high resolution video playback due to unimplemented
    changeType operation.
  + Ensure GSubprocess uses posix_spawn() again and inherit file
    descriptors.
  + Fix player stucking in buffering (paused) state for progressive
    streaming.
  + Do not try to preconnect on link click when link preconnect
    setting is disabled.
  + Fix close status code returned when the client closes a
    WebSocket in some cases.
  + Fix media player duration calculation.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-46691.
* Tue Nov  8 2022 mgorse@suse.com
- Update to version 2.38.0 boo#1205121 boo#1205122):
  + New media controls UI style.
  + Add new API to set WebView’s Content-Security-Policy for web
    extensions support.
  + Make it possible to use the remote inspector from other
    browsers using WEBKIT_INSPECTOR_HTTP_SERVER env var.
  + MediaSession is enabled by default, allowing remote media
    control using MPRIS.
  + Add support for PDF documents using PDF.js.
  + Security fixes: CVE-2022-32888, CVE-2022-32923, CVE-2022-42863,
    CVE-2022-48503, CVE-2022-32933.
* Mon Sep 19 2022 mgorse@suse.com
- Update to version 2.36.8 (boo#1203530):
  + Fix jumpy elements when scrolling GitLab and other web sites.
  + Fix WebKitWebView:web-process-terminated signal not being
    emitted for the first web view when sandboxing is enabled.
  + Fix hang when opening HTML <select> elements in GTK4 builds.
  + Fix kinetic scrolling with elements that use overflow
    scrolling.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-32886, CVE-2022-32912, CVE-2023-25358,
    CVE-2023-25360, CVE-2023-25361, CVE-2023-25362, CVE-2023-25363.
* Fri Aug 26 2022 mgorse@suse.com
- Update to version 2.36.7 (boo#1202807):
  - Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-32893.
* Wed Aug 24 2022 mgorse@suse.com
- Update to version 2.36.6
  + Fix handling of touchpad scrolling on GTK4 builds
  + Fix WebKitGTK not allowing to be used from non-main threads
    (boo#1202169)
  + Fix several crashes and rendering issues
* Fri Jul 29 2022 mgorse@suse.com
- Update to version 2.36.5 (boo#1201980):
  + Add support for PAC proxy in the WebDriver implementation.
  + Fix video playback when loaded through custom URIs, this fixes
    video playback in the Yelp documentation browser.
  - Fix WebKitWebView::context-menu when using GTK4.
  - Fix LTO builds with GCC.
  - Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-32792, CVE-2022-32816.
- Drop webkit2gtk3-fix-build.patch: fixed upstream.
* Tue Jul  5 2022 mgorse@suse.com
- Update to version 2.36.4 (boo#1201221):
  + Fix the new ATSPI accessibility implementation to add the missing
    Collection interface for the loaded document.
  + Fix the MediaSession implementation to make the MPRIS object
    names more sandbox friendly, which plays better with Flatpak
    and WebKit's own Bubblwrap-based sandboxing.
  + Fix leaked Web Processes in some particular situations.
  + Fix the build with media capture support enabled.
  + Fix cross-compilation when targeting 64-bit ARM.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-22677, CVE-2022-26710.
- Add webkit2gtk3-fix-build.patch: fix the build.
* Wed Jun  1 2022 mgorse@suse.com
- Update to version 2.36.3 (boo#1200106):
  + Support capturing already encoded video streams, which takes
    advantage of encoding done in hardware by devices which support
    this feature.
  + Avoid using experimental GStreamer elements for video demuxing.
  + Avoid using the legacy GStreamer VA-API decoding plug-ins,
    which often cause rendering issues and are not much maintained.
    Their usage can be re-enabled setting
    WEBKIT_GST_ENABLE_LEGACY_VAAPI=1 in the environment.
  + Fix playback of YouTube streams which use dynamic ad insertion.
  + Fix display capture with Pipewire.
  + Fix the build without the X11 target when X11 headers are not
    present.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-26700, CVE-2022-26709, CVE-2022-26716,
    CVE-2022-26717, CVE-2022-26719.
- Drop webkit2gtk3-old-ruby.patch: fixed upstream.
* Wed Jun  1 2022 mgorse@suse.com
- Update to version 2.36.2:
  + Fix some pages showing empty content boxes when using GTK4.
  + Fix the build with accessibility disabled.
  + Fix the build with newer Ruby versions.
  + Fix several crashes and rendering issues.
* Wed Jun  1 2022 mgorse@suse.com
- Update to version 2.36.1 (boo#1199287):
  + Fix the build with accessibility disabled.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-30293.
* Fri Apr 22 2022 mgorse@suse.com
- Disable gold linker. It is unmaintained and now disabled on
  factory.
- Switch to gcc 11.
- Increase mem_per_process. Attempt to fix sporadic bild failure
  (bsc#1198743).
* Tue Apr 12 2022 mgorse@suse.com
- Update to version 2.36.0 (boo#1198290):
  + Add new accessibility implementation using ATSPI DBus
    interfaces instead of ATK.
  + Add support for requestVideoFrameCallback.
  + Change hardware-acceleration-policy setting default value to
    always.
  + Add support for media session.
  + Add new API to set HTTP response information to custom uri
    schemes.
  + Make user interactive threads (event handler, scrolling, …)
    real time in linux.
  + Security fixes: CVE-2022-22624, CVE-2022-22628, CVE-2022-22629,
    CVE-2022-22662.
- Rebase no-forced-sse.patch.
- Drop fix-warnings.patch and webkit2gtk3-link-fix.patch: fixed upstream.
- Add webkit2gtk3-old-ruby.patch: fix a build failure.
* Thu Feb 17 2022 mgorse@suse.com
- Update to version 2.34.6 (boo#1196133):
  + Fix accessibility not working when the Bubblewrap sandbox is
    enabled.
  + Fix rendering of scrollbars when overlay scrollbars are
    disabled.
  + Fix the build when the X11 support is disabled.
  + Fix the build in a number of situations where the main OpenGL
    library is not called libGL or libgl, as is the case on
    systems that use libglvnd.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-22620.
* Wed Feb  9 2022 mgorse@suse.com
- Update to version 2.34.5 (boo#1195735):
  + Improve VP8 codec selection when using GStreamer 1.20.
  + Fix connecting to the accessiblity bus when using the
    Bubblewrap sandbox.
  + Fix links being incorrectly activated when starting a pinch
    zoom gesture.
  + Fix touch-based scrolling.
  + Fix the build with recent toolchains based on GCC 12 and on
    older ones as included e.g. in Ubuntu 18.04.
  + Fix the build with ICU 60, version 61 is no longer required.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2022-22589, CVE-2022-22590, CVE-2022-22592,.
  + Drop webkit2gtk3-gcc12.patch: fixed upstream.
* Mon Jan 31 2022 bjorn.lie@gmail.com
- Update constraints for disk space even more, now at 20 gig.
* Mon Jan 24 2022 mgorse@suse.com
- Add webkit2gtk3-gcc12.patch: fix the build with gcc 12.
- Require glib2 2.44 to match source.
* Fri Jan 21 2022 bjorn.lie@gmail.com
- Update to version 2.34.4 (boo#1195064):
  + Fix several crashes and rendering issues.
  + This release fixes numerous security issues, including an
    especially severe issue that allowed websites to read the names
    of IndexedDB databases created by other websites.
  + Security fixes: CVE-2021-30934, CVE-2021-30936, CVE-2021-30951,
    CVE-2021-30952, CVE-2021-30953, CVE-2021-30954, CVE-2021-30984,
    CVE-2022-22594, CVE-2022-22637.
* Wed Jan 19 2022 fcrozat@suse.com
- Update _constraints, needs more disk space to build.
* Tue Dec 21 2021 mgorse@suse.com
- Update to version 2.34.3 (boo#1194019):
  + Make audio tools (like mixers) display the actual name of the
    application producing sound, instead of a generic one.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2021-30887, CVE-2021-30890.
* Tue Dec 14 2021 yfjiang@suse.com
- Typo fix for %%define usegcc10.
* Tue Dec 14 2021 dimstar@opensuse.org
- Introduce usegcc10 %%define in order to have the condition
  (0%%{?sle_version} && 0%%{?sle_version} <= 150400) only at one
  point.
- Correct a very old "Obsoletes: webkit2gtk3-plugin-process-gtk2"
  to be a versioned obsoletes.
* Tue Dec 14 2021 yfjiang@suse.com
- Make the earlier Obsoletes: libwebkit2gtk3-lang compliant with:
  https://en.opensuse.org/openSUSE:Upgrade_dependencies_explanation#Renaming_a_package
* Wed Dec  8 2021 yfjiang@suse.com
- Add Obsoletes of the old-name -lang package to be ready for
  updating from it. This change is necessary for the gtk3-soup2
  flavor.
* Sat Nov 27 2021 mgorse@suse.com
- Update to version 2.34.2:
  + Fix scrolling issues when pressing Home and PgDown keys.
  + Update effective appearance after web process switch on
    navigation.
  + Fix the build with video disabled.
* Mon Nov  1 2021 bjorn.lie@gmail.com
- Add pkgconfig(libavif) BuildRequires and pass USE_AVIF=ON to
  cmake, build avif decoding support.
* Mon Nov  1 2021 mgorse@suse.com
- Add wayland-protocols to BuildRequires.
* Tue Oct 26 2021 mgorse@suse.com
- Add webkit2gtk3-link-fix.patch: taken from upstream, fixes the
  build on SLE-15-SP4.
- Use gcc10 package on SLE <= 15-SP4. Gcc 7 is currently the
  default there.
- Update gcc-c++ version requirement to match the cmake check.
* Thu Oct 21 2021 mgorse@suse.com
- Update to version 2.34.1 (boo#1191937):
  + Update user agent browser versions.
  + Fix a crash with GTK >= 3.24.30.
  + Fix a crash when loading videos on reddit.
  + Fix file type detection when application calls
    g_desktop_app_info_set_as_default_for_extension() passing html.
  + Security fixes: CVE-2021-42762.
* Wed Sep 29 2021 dimstar@opensuse.org
- Add libjavascriptcoregtk-4_0-18 and llibwebkit2gtk-4_0-37 to
  baselibs.conf: provide those libraries as multilib version.
* Wed Sep 29 2021 dimstar@opensuse.org
- Rename -lang packages to WebKit2GTK-%%{_apiver}, making the
  translations between the three flavors co-exist.
* Wed Sep 22 2021 dimstar@opensuse.org
- Update to version 2.34.0 (boo#1192063):
  + Fix another regression in JavaScriptCore on 32bit systems.
  + Security fixes: CVE-2021-30846, CVE-2021-30851, CVE-2021-30818,
    CVE-2021-30823, CVE-2021-30884, CVE-2021-30888, CVE-2021-30889,
    CVE-2021-30897, CVE-2021-45481, CVE-2021-45483.
* Mon Sep 20 2021 mgorse@suse.com
- Update to version 2.33.91:
  + Use the right display refresh monitor for animations in
    accelerated compositng mode.
  + Fix several issues in JavaScriptCore on 32bit systems.
  + Prefer python3 over python2 in CMake.
* Mon Sep 20 2021 mgorse@suse.com
- Update to version 2.33.90:
  + Show TLS protocol version and ciphersuite name in the
    inspector when building with libsoup3.
  + Add multi-track support to media backend.
  + Avoid strong alias computations in font fallback code.
  + Fix deadlock tearing down pipeline when using fallback sink.
  + Fix the build with gtk-doc enabled.
  + Fix several crashes and rendering issues.
- Add fix-warnings.patch: silence return-type warnings.
* Mon Sep 20 2021 dimstar@opensuse.org
- Add a 3rd flavor: gtk3 with libsoup2 (which retains compatibility
  to the olderversions, identified as API version 4.0).
* Mon Sep 20 2021 dimstar@opensuse.org
- Add _multibuild file and enable build of webkit2gtk4.
* Mon Sep 20 2021 dimstar@opensuse.org
- Update to version 2.33.3:
  + Add support for display capture.
  + Add new API to access/modify capture devices states.
  + Add new API to configure the memory pressure handler.
  + Add support for client side certifiates authentication.
  + Add support color-schemes CSS property.
  + Add support for dark scrollbars.
  + Keep GtkSettings used by web processes in sync with the
    settings set in the UI process.
  + Add support for drawing the scrollbars corner.
  + Allow to opt-out of GL rendering at runtime for media player.
  + Add support for A420 compositing in media player.
  + Improve pinch to zoom gesture in accerlerated compositing mode.
  + Fix cookies configuration after a network process crash.
  + Fix touchscreen navigation swipe when the page scrolls
    horizontally.
  + Fix rendering of elliptic radial gradients.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Drop fix-lto.patch: fixed upstream.
- Add pkgconfig(lcms2) BuildRequires: new dependency.
- Replace pkgconfig(libsoup-2.4) BuildRequires with
  pkgconfig(libsoup-3.0): Follow upstreams port to Libsoup 3.0.
* Sun Sep 19 2021 mgorse@suse.com
- Update to version 2.32.4 (boo#1190701):
  + Do not append .asc extension to downloaded text/plain files.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2021-30848, CVE-2021-30849, CVE-2021-30858,
    CVE-2021-30809, CVE-2021-30836, CVE-2021-45482.
- Drop fix-lto.patch: fixed upstream.
* Tue Aug 10 2021 mliska@suse.cz
- Enable LTO by using upstream patch fix-lto.patch.
* Thu Aug  5 2021 yfjiang@suse.com
- Drop unneeded patch on Leap and SLE by now:
  webkit2gtk3-restore-npapi.patch (bsc#1189105).
* Thu Jul 29 2021 yfjiang@suse.com
- Add BuildRequires pkgconfig(glproto) for SLE and Leap which have
  not included the new packaging of the relevant headers.
* Mon Jul 26 2021 mgorse@suse.com
- Update to version 2.32.3 (boo#1188697):
  + Properly set the cookies settings after a network process
    crash.
  + Fix accessibility tree after a cross site navigation with PSON
    enabled.
  + Ensure WebKitScriptWorld::window-object-cleared signal is
    always emitted.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2021-21775, CVE-2021-21779, CVE-2021-30663,
    CVE-2021-30665, CVE-2021-30689, CVE-2021-30720, CVE-2021-30734,
    CVE-2021-30744, CVE-2021-30749, CVE-2021-30795, CVE-2021-30797,
    CVE-2021-30799.
- Fix webkit2gtk3-restore-npapi.patch to install the plugin
    process.
- Disable WPE renderer: our FDO backend is now too old.
* Mon Jul 19 2021 mgorse@suse.com
- Update to version 2.32.2:
  + Improve calculation of initial WebKitWebView size.
  + Fix kinetic scrolling on touchpad with async scrolling off.
  + Fix a crash on empty drag operation in X11.
  + Fix rendering on HiDPI /4k screen and scaling.
  + Handle null native surface for for surfaceless rendering.
  + Fix JavaScriptCore crash on 32-bit big endian systems.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2021-30758.
* Wed May 19 2021 mgorse@suse.com
- Update to version 2.32.1:
  + Support building against the Musl C library.
  + Support building against ICU version 69 or newer.
  + Improve handling of Media Capture devices.
  + Improve WebAudio playback.
  + Improve video orientation handling.
  + Improve seeking support for MSE playback.
  + Improve flush support in EME decryptors.
  + Fix HTTP status codes for requests done through a custom URI
    handler.
  + Fix the Bubblewrap sandbox in certain 32-bit systems.
  + Fix inconsistencies between the WebKitWebView.is-muted property
    state and values returned by
    webkit_web_view_is_playing_audio().
  + Fix the build with ENABLE_VIDEO=OFF.
  + Fix wrong timestamps for long-lived cookies.
  + Fix UI process crash when failing to load favicons.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Drop webkit2gtk3-icu69.patch: fixed upstream.
* Wed Apr 28 2021 dimstar@opensuse.org
- Add webkit2gtk3-icu69.patch: Fix build with ICU 69:
  + ICU 69 deprecates ubrk_safeClone in favor of ubrk_clone.
* Mon Apr 12 2021 mgorse@suse.com
- Per discussion with maintenance, let's not remove features that
  customers could possibly be using:
- Add webkit2gtk3-restore-npapi.patch: restore NPAPI plugin
  support. Reverts webkit#215503.
* Tue Apr  6 2021 mgorse@suse.com
- Update to version 2.32.0 (boo#1184155):
  + Fix the authentication request port when URL omits the port.
  + Fix iframe scrolling when main frame is scrolled in async
    scrolling mode.
  + Stop using g_memdup.
  + Show a warning message when overriding signal handler for
    threading suspension.
  - Fix the build on RISC-V with GCC 11.
  - Fix several crashes and rendering issues.
  + Security fixes: CVE-2021-1788, CVE-2021-1844, CVE-2021-1871
  + Changes in version 2.30.6 (boo#1184262):
  + Update user agent quirks again for Google Docs and Google Drive.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2020-27918, CVE-2020-29623, CVE-2021-1765,
  CVE-2021-1789, CVE-2021-1799, CVE-2021-1801, CVE-2021-1870.
- Remove webkit-font-scaling.patch: contained in upstream
- Drop original SLE 15 support from the spec. Drop
  webkit-process.patch and old-wayland-scanner.patch; they are not
  needed for SP2.
- Pass ENABLE_GAMEPAD=OFF to cmake, since we don't have manette.
- Add glproto-devel to BuildRequires: now needed for the build on
  SLE 15.
* Fri Apr  2 2021 mgorse@suse.com
- Update to version 2.32.0 (boo#1184155):
  + Fix the authentication request port when URL omits the port.
  + Fix iframe scrolling when main frame is scrolled in async
    scrolling mode.
  + Stop using g_memdup.
  + Show a warning message when overriding signal handler for
    threading suspension.
  - Fix the build on RISC-V with GCC 11.
  - Fix several crashes and rendering issues.
  + Security fixes: CVE-2021-1788, CVE-2021-1844, CVE-2021-1871,
    CVE-2021-30682.
- Drop old-wayland-scanner.patch and webkit-process.patch, and also
  drop support for Leap 15.0 and 15.1, since they are no longer
  supported.
* Tue Mar 23 2021 mgorse@suse.com
- Update to version 2.31.91:
  + Make WebKitSecurityOrigin a simple data store for <protocol,
    host, port> and deprecate webkit_security_origin_is_opaque().
  + Fix user agent again to work on several google websites.
  + Fix web view url on web process terminate signals.
  + Fix preferred language overrides sent to the web process.
  + Fix the build in i386.
  + Translation updates: Simplified Chinese.
- Drop webkitgtk-i586-build-fix.patch: fixed upstream.
- Disable webkit-process.patch: needs to be rebased or dropped.
* Mon Mar 22 2021 mgorse@suse.com
- Add webkitgtk-i586-build-fix.patch: fix build on i586
  (webkit#222480).
* Mon Mar 22 2021 mgorse@suse.com
- Update to version 2.31.90:
  + Add permission request API for MediaKeySystem access.
  + Fix rendering when using opacity filters on hardware
    accelerated layers.
  + Fix flatpak-spawn subsandbox to not clear environment
    variables.
  + Ensure a URI scheme handler can't be registered multiple times.
  + Fix several crashes and rendering issues.
  + The minimum required GStreamer version is now 1.14.
  + CEA-608 closed captions support (requires
    WEBKIT_GST_USE_PLAYBIN3=1 environment variable).
  - Advertise CBCS decryption and VP9 support in Thunder.
  - Advertise DASH as supported in the media player.
  - Improved support for playbin3.
  - Translation updates: Ukrainian.
- Up required gstreamer and gtk3 versions.
* Mon Mar 22 2021 gmbr3@opensuse.org
- Update to version 2.31.1:
  + Remove support for NPAPI plugins.
  + Enable the web process cache when PSON is enabled too.
  + TLS errors and proxy settings APIs have been moved from
    WebKitContext to WebKitWebsiteDataManager.
  + Add new API to remove individual scripts/stylesheets using
    WebKitUserContentManager.
  + Correctly apply the system font scaling factor.
  + Show main loop frames information in the web inspector.
- Remove webkit-font-scaling.patch: contained in upstream
- New build requirement: pkgconfig(manette-0.2).
* Sun Mar 21 2021 mgorse@suse.com
- Update to version 2.30.6 (boo#1184262):
  + Update user agent quirks again for Google Docs and Google Drive.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2020-27918, CVE-2020-29623, CVE-2021-1765
    CVE-2021-1789, CVE-2021-1799, CVE-2021-1801, CVE-2021-1870,
    CVE-2021-21806.
* Fri Feb 19 2021 guillaume.gardet@opensuse.org
- Update _constraints for armv6/armv7 (bsc#1182719)
* Sat Feb 13 2021 mgorse@suse.com
- Update to version 2.30.5 (boo#1182286):
  + Bring back the WebKitPluginProcess installation that was
    removed by mistake.
  + Fix RunLoop objects leaked in worker threads.
  + Fix aarch64 llint build with JIT disabled.
  + Use Internet Explorer quirk for Google Docs.
  + Security fixes: CVE-2020-13558.
- Drop gir-multilib.patch: fixed upstream.
* Wed Jan 20 2021 bjorn.lie@gmail.com
- Add gir-multilib.patch: Fix multilib conflict in gir files.
- Disable gold linker for ppc64le
* Tue Jan 19 2021 badshah400@gmail.com
- Add webkit-font-scaling.patch: Fix system font scaling not
  applied to 'font-size: XXXpt'; patch taken from upstream and
  rebased to apply cleanly
  (https://bugs.webkit.org/show_bug.cgi?id=218450).
- Pass `-q` to setup to disable printing long list of files
  extracted from source tarball.
* Tue Dec 15 2020 dimstar@opensuse.org
- Update to version 2.30.4:
  + Fix text data sent with WebSockets when using libsoup < 2.68.
  + Fix the rendering on Raspberry Pi 3 using the proprietary video
    driver.
  + Fix clipping of descedant layers of a mask layer.
  + Fix the build with ICU 68.1.
- Drop upstream merged patch:
  + 0001-ICU-68.1-no-longer-exposes-FALSE-and-TRUE-macros-by-.patch
* Thu Dec  3 2020 mgorse@suse.com
- Add old-wayland-scanner.patch for 15.0/15.1: support older
  wayland-scanner. Also renumber patches to group
  15.0/15.1-specific patches together.
- Have the libwebkit2gtk package require libjavascriptcoregtk of
  the same version (boo#1171531).
* Wed Dec  2 2020 dimstar@opensuse.org
- 0001-ICU-68.1-no-longer-exposes-FALSE-and-TRUE-macros-by-.patch:
  ICU 68.1 no longer exposes FALSE and TRUE macros by default.
* Sun Nov 22 2020 mgorse@suse.com
- Update to version 2.30.3 (boo#1179122 boo#1179451):
  + Add new build option USE(64KB_PAGE_BLOCK).
  + Fix backdrop filters with rounded borders.
  + Fix scrolling iframes when async scrolling is enabled.
  + Allow applications to handle drag and drop on the web view
    again.
  + Update Outlook user agent quirk.
  + Fix the build with video support disabled.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2020-13584, CVE-2020-9983, CVE-2020-13543.
- Drop webkit2gtk3-fdo-soname.patch: fixed upstream.
- Rebase webkit-process.patch.
* Fri Oct 23 2020 dimstar@opensuse.org
- Update to version 2.30.2:
  + Fix scrolling when smooth scrolling is enabled in async
    scrolling mode.
  + Fix WebSocket requests with same-site cookies.
  + Fix TLS certificate information for service workers.
  + Handle chassis type when its value is quoted.
  + Fix the build with ENABLE_MEDIA_STREAM enabled and
    ENABLE_WEB_RTC_DISABLED.
  + Fix the build with ENABLE_GAMEPAD enabled.
  + Fix several crashes and rendering issues.
* Wed Sep 30 2020 mgorse@suse.com
- Enable c_loop on aarch64: currently needed for compilation to
  succeed with JIT disabled. Also disable sampling profiler, since
  it conflicts with c_loop (boo#1177087).
* Tue Sep 22 2020 mgorse@suse.com
- Update to version 2.30.1:
  + Bring back the environment variable to force single process
    mode when PSON is disabled.
  + Fix downloads started by an ephemeral web context.
  + Updated translations.
* Mon Sep 14 2020 mgorse@suse.com
- Update to version 2.30.0:
  + Fix NTLM authentication.
  + Don't try to use SHM on wayland with older wpebackend-fdo.
  + Fix the build due to seccomp.h header not found.
  + Security fixes: CVE-2020-9947, CVE-2020-9948, CVE-2020-9951,
    CVE-2021-1817, CVE-2021-1820, CVE-2021-1825, CVE-2021-1826,
    CVE-2021-30661.
- Drop seccomp-build-fix.patch and wpe-shm-check.patch: fixed
  upstream.
* Mon Sep  7 2020 mgorse@suse.com
- Add wpe-shm-check.patch: make SHM initialization fail for
  wpebackend-fdo < 1.7.0.
* Sun Sep  6 2020 mgorse@suse.com
- Add seccomp-build-fix.patch: pass seccomp include directory to
    g++.
- Re-enable bubblewrap sandbox for SLE-15-SP2 and Tumbleweed.
* Sat Sep  5 2020 dimstar@opensuse.org
- Update to version 2.29.92:
  + Fix user agent header after a redirect when a new quirk is
    required.
  + Stop using firefox user agent quirk for google docs.
  + Fix rendering frames timeline panel in web inspector.
  + Fix per-thread cpu usage in web inspector.
  + Fix several crashes and rendering issues.
- Changes from version 2.29.91:
  + Fix a web process crash introduced in 2.29.90.
- Changes from version 2.29.90:
  + Fix font variation settings when font smoothing setting is also
    present.
  + Fix HTML drag and drop operations.
  + Fix argument order for clone syscall seccomp filter on s390x.
  + Fix a crash when selecting text.
  + Fix several crashes and rendering issues.
- Changes from version 2.29.4:
  + Add support for backdrop filters.
  + Add support for text-underline-offset and
    text-decoration-thickness.
  + Add OpenCDM and AV1 support to media backend.
  + Add new API to get ITP data summary.
  + Use mobile user-agent on tablets.
  + Fix several crashes and rendering issues.
- Changes from version 2.29.3:
  + Add webkit_authentication_request_get_security_origin.
  + Change the cookies accept policy to always when no-third-party
    is set and ITP is enabled.
  + Fix web process hangs on large GitHub pages.
  + Bubblewrap sandbox should not attempt to bind empty paths.
  + Add support for sndio to bubblewrap sandbox.
  + Also handle dark themes when the name ends with -Dark.
  + Fix a race condition causing a crash in media player.
  + Fix several crashes and rendering issues.
- Changes from version 2.29.2:
  + Add Intelligent Tracking Prevention (ITP) support.
  + Add support for video formats in img elements.
  + Add API to handle video autoplay policy that now defaults to
    disallow autoplay videos with audio.
  + Add API to mute a web view.
  + Add API to allow applications to handle the HTTP authentication
    credential storage.
  + Add a WebKitSetting to set the media content types requiring
    hardware support.
  + Fix a crash during drag an drop due to a bug introduced in
    2.29.1.
  + Do not start page load during animation in back/forward
    gesture.
  + Fix several crashes and rendering issues.
- Changes from version 2.29.1:
  + Stop using GTK theming to render form controls.
  + Add API to disable GTK theming for scrollbars too.
  + Fix several race conditions and threading issues in the media
    player.
  + Add USER_AGENT_BRANDING build option.
  + Add paste as plain text option to the context menu for rich
    editable content.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Rebase webkit2gtk3-fdo-soname.patch.
- Add pkgconfig(libsystemd) BuildRequires: new dependency.
* Thu Aug  6 2020 jengelh@inai.de
- Add no-forced-sse.patch, cure execution of illegal instruction
  in i586 firefox.
* Wed Jul 29 2020 mgorse@suse.com
- Update to version 2.28.4 (boo#1174662):
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2020-9862, CVE-2020-9893, CVE-2020-9894,
    CVE-2020-9895, CVE-2020-9915, CVE-2020-9925.
* Fri Jul 10 2020 bjorn.lie@gmail.com
- Update to version 2.28.3 (boo#1173998):
  + Enable kinetic scrolling with async scrolling.
  + Fix web process hangs on large GitHub pages.
  + Bubblewrap sandbox should not attempt to bind empty paths.
  + Fix threading issues in the media player.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2020-9802, CVE-2020-9803, CVE-2020-9805,
    CVE-2020-9806, CVE-2020-9807, CVE-2020-9843, CVE-2020-9850,
    CVE-2020-13753, CVE-2020-9952.
* Mon Apr 27 2020 bjorn.lie@gmail.com
- Update to version 2.28.2 (boo#1170643):
  + Fix excessive CPU usage due to GdkFrameClock not being stopped.
  + Fix UI process crash when EGL_WL_bind_wayland_display extension
    is not available.
  + Fix position of select popup menus in X11.
  + Fix playing of Youtube 'live stream'/H264 URLs.
  + Fix a crash under X11 when cairo uses xcb.
  + Fix the build in MIPS64.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2020-3899.
* Wed Apr 15 2020 bjorn.lie@gmail.com
- Update to version 2.28.1 (boo#1169658):
  + Fix position of default option element popup windows under
    Wayland.
  + Fix rendering after a cross site navigation with PSON enabled
    and hardware acceleration forced.
  + Fix a crash in nested wayland compositor when closing a tab
    with PSON enabled.
  + Update Chrome and Firefox versions in user agent quirks.
  + Fix a crash with bubblewrap sandbox enabled.
  + Fix a crash in JavaScriptCore in ppc64el.
  + Fix the build with GStreamer 1.12.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2020-11793.
- Drop webkit2gtk3-gstreamer-build-fix.patch: Fixed upstream.
* Thu Apr  2 2020 mgorse@suse.com
- Add webkit2gtk3-gstreamer-build-fix.patch: fix build with
  gstreamer 1.12 (webkit#209296).
- Rebase webkit-process.patch.
- Use WebKit defaults for ENABLE_JIT and USE_SYSTEM_MALLOC, except
  for aarch64. WebKit now sets reasonable defaults based on
  architecture. Disable on aarch64 in case a user is still using
  the kernel-64kb package.
- Use bubblewrap, xdg-dbus-proxy, wpe, and wpebackend-fdo on 15.2;
  they had been unintentionally excluded.
- Increase mem_per_process; otherwise fails on SLE/Leap.
* Thu Mar 12 2020 bjorn.lie@gmail.com
- Update to version 2.28.0 (boo#1165528):
  + Add API to enable Process Swap on (Cross-site) Navigation.
  + Add user messages API for the communication with the web
    extension.
  + Add support for same-site cookies.
  + Service workers are enabled by default.
  + Add support for Pointer Lock API.
  + Add flatpak sandbox support.
  + Make ondemand hardware acceleration policy never leave
    accelerated compositing mode.
  + Always use a light theme for rendering form controls.
  + Add about:gpu to show information about the graphics stack.
  + Security fixes: CVE-2020-10018, CVE-2020-3885, CVE-2020-3894,
    CVE-2020-3895, CVE-2020-3897, CVE-2020-3900, CVE-2020-3901,
    CVE-2020-3902, CVE-2021-30762.
- Drop webkit2gtk3-ppc-build-fix.patch: Fixed upstream.
* Fri Feb 28 2020 bjorn.lie@gmail.com
- Disable webkit-process.patch: Needs rebase, and furthermore it
  should not be applied for Leap 15.2 as it is today.
* Thu Feb 27 2020 bjorn.lie@gmail.com
- Update to version 2.27.91:
  + Update user agent quirks to fix the unsupported browser message
    in several google services.
  + Fix several compile warnings with GCC 10.
  + Fix the build with GCC 10.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Tue Feb 18 2020 mgorse@suse.com
- Add webkit2gtk3-ppc-build-fix.patch: fix ppc64le build failure on
  SLE 15.
* Fri Feb 14 2020 bjorn.lie@gmail.com
- Update to version 2.27.90:
  + Add support for same-site cookies.
  + Add flatpak sandbox support.
  + Enable WebAudio and WebGL by default in WebKitSettings.
  + Add a setting to disallow top level navigation to a data URI.
  + Add support for the -webkit-font-smoothing CSS property.
  + Always use a light theme for rendering form controls.
  + Stop making the Web Inspector windows transient.
  + Ensure mouse cursor is hidden during fullscreen video playback.
  + Add support for inspecting service workers to the remote
    inspector.
  + Fix several crashes and rendering issues.
- Changes from version 2.27.4:
  + Add API for input methods.
  + Add API to serialize/deserialize a JSCValue to/from a JSON
    string.
  + Add support for strict secure cookies.
  + Add support for saving data from remote inspector.
  + Make ondemand hardware acceleration policy never leave
    accelerated compositing mode.
  + Fix rendering of conic gradients in high resolution displays.
  + Fix special combination characters not respecting the keystroke
    order when high CPU load.
  + Honor the IndexedDB directory set in WebsiteDataManager.
  + Fix rendering of text when there’s an initial advance in the
    text run.
  + Fix web process crash when displaying a KaTeX formula.
  + Fix network process crash with PSON enabled.
  + Fix several crashes and rendering issues.
- Changes from version 2.27.3:
  + Add support for Pointer Lock API.
  + Improve performance when falling back to system fonts.
  + Stop using DBus for the remote inspector implementation to
    improve the performance of both WebDriver and remote inspector.
  + Implement support for new ARIA roles: code, strong, emphasis,
    generic.
  + Fix handling of content type with new custom protocols
    implementation.
  + Make image decoders fully thread safe.
  + Add support for get page source command in WebDriver.
  + Add support for network proxy capabilities in WebDriver.
  + Add support for new window command in WebDriver.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Changes from version 2.27.2:
  + Add user messages API for the communication with the web
    extension.
  + Enable service workers by default.
  + Add support for saving data in Web Inspector.
  + More navigation gesture improvement.
  + Fix the build with WebDriver disabled.
  + Show also client EGL extensions in about:gpu.
  + Disable accelerated compositing when we fail to initialize the
    EGL dispaly under Wayland.
  + Fix several crashes and rendering issues.
- Changes from version 2.27.1:
  + Enable async scrolling when accelerating compositing policy is
    ‘always’.
  + Add about:gpu to show information about the graphics stack.
  + Add API to enable Process Swap on (Cross-site) Navigation, that
    is now disabled by default.
  + Add WebKitWebView:page-id property.
  + Improve swipe navigation gesture style.
  + Fix several crashes and rendering issues.
- Rebase webkit2gtk3-fdo-soname.patch.
* Fri Feb 14 2020 bjorn.lie@gmail.com
- Update to version 2.26.4 (boo#1163809):
  + Always use a light theme for rendering form controls.
  + Fix the build with WPE renderer disabled.
  + Fix the build with OpenGL disabled.
  + Fix the build with GCC 10.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2020-3862, CVE-2020-3864, CVE-2020-3865,
    CVE-2020-3867, CVE-2020-3868.
* Sat Jan 25 2020 dimstar@opensuse.org
- No longer recommend -lang: supplements are in use
* Wed Jan 22 2020 bjorn.lie@gmail.com
- Update to version 2.26.3 (boo#1161719):
  + Fix issues while trying to play a video on NextCloud.
  + Make sure the GL video sink uses a valid WebKit shared GL
    context.
  + Fix vertical alignment of text containing arabic diacritics.
  + Fix build with icu 65.1.
  + Fix page loading errors with websites using HSTS.
  + Fix web process crash when displaying a KaTeX formula.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2019-8835, CVE-2019-8844, CVE-2019-8846.
- Drop webkit2gtk3-icu-build-fix.patch: Fixed upstream.
* Thu Dec 19 2019 bjorn.lie@gmail.com
- Start using webkitgtk default gigacage malloc via passing
  USE_SYSTEM_MALLOC=OFF to cmake.
* Thu Dec 19 2019 mgorse@suse.com
- Add webkit-process.patch: use single web process for evolution
  and geary on 15.0 (boo#1159329 glgo#GNOME/evolution#587).
* Mon Nov 11 2019 mgorse@suse.com
- Add webkit2gtk3-icu-build-fix.patch: fix build with icu 65.1.
* Thu Nov  7 2019 mgorse@suse.com
- Only use wpe and xdg-dbus-proxy/bubblewrap for TW and
  SLE-15-SP2 / leap 15.2.
- Don't pass -DENABLE_BUBBLEWRAP_SANDBOX=ON; it is on by default.
- Remove conditionals for EOL versions of openSUSE.
- Always build with python3; remove the conditional.
* Wed Nov  6 2019 bjorn.lie@gmail.com
- Update to version 2.26.2 (boo#1156318):
  + Improve performance of querying system fallback fonts.
  + Don't use prgname in dbus-proxy socket path.
  + Fix thread-safety issues in image decoders.
  + Fix the build with WebDriver disabled.
  + Disable accelerated compositing when we fail to initialize the
    EGL dispaly under Wayland.
  + Fill the objects category in emoji picker.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2019-8812, CVE-2019-8814.
* Thu Sep 26 2019 bjorn.lie@gmail.com
- Enable sandbox again (pass -DENABLE_BUBBLEWRAP_SANDBOX=ON to
  cmake).
- Move bubblewrap and xdg-dbus-proxy Requires from main package to
  main library package libwebkit2gtk-4_0-37, they are needed at
  runtime, and there is no webkit2gtk3 package that we can install.
* Mon Sep 23 2019 bjorn.lie@gmail.com
- Update to version 2.26.1:
  + Fix MSE media player with GStreamer 1.14.
  + Fix HTML alternate loads never finishing.
  + Fix web view initialization delay on fisrt load.
  + Validate user agent string set via API.
  + Fix a crash when a web view is destroyed with accelerated
    compositing mode enabled.
  + Fix EGL initialization with newer versions of Mesa.
  + Do not enable the sandbox inside docker.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2019-8783, CVE-2019-8811, CVE-2019-8813,
    CVE-2019-8816, CVE-2019-8819, CVE-2019-8820, CVE-2019-8823.
* Thu Sep 19 2019 mgorse@suse.com
- Add webkit2gtk3-fdo-soname.patch: don't try to open WPE backend
  with an unversioned soname.
* Tue Sep 17 2019 mgorse@suse.com
- Enable pkgconfig(wpe-1.0) and pkgconfig(wpebackend-fdo-1.0)
  BuildRequires and stop passing DUSE_WPE_RENDERER=OFF to cmake.
* Thu Sep 12 2019 bjorn.lie@gmail.com
- Test disable sandbox, does this fix epiphany?
  (pass -DENABLE_BUBBLEWRAP_SANDBOX=OFF to cmake).
* Mon Sep  9 2019 bjorn.lie@gmail.com
- Update to version 2.26.0 (boo#1155321):
  + Add support for subprocess sandboxing.
  + Add support for HSTS (HTTP Strict Transport Security).
  + Use libwpe with fdo backend to implement accelerated
    compositing under wayland.
  + Remove support for GTK2 NPAPI plugins.
  + Add support for datalist element in text input fields.
  + Show the emoji chooser popover for editable content.
  + Improve rendering of form controls when GTK theme is dark.
  + Fix rendering artifacts in youtube volume button and github
    comment box.
  + Single process model has been deprecated for security reasons.
  + Security fixes: CVE-2019-8625, CVE-2019-8720, CVE-2019-8769,
    CVE-2019-8771, CVE-2019-8710, CVE-2019-8743, CVE-2019-8764,
    CVE-2019-8766, CVE-2019-8782, CVE-2019-8808, CVE-2019-8815,
    CVE-2021-30666, CVE-2021-30761.
* Tue Sep  3 2019 bjorn.lie@gmail.com
- Update to version 2.25.92:
  + Add WEBKIT_USE_SINGLE_WEB_PROCESS environment variable to force
    single process model in all WebKitWebContext. This is a
    temporary solution for applications still depending on the
    single process mode behavior. It will be only available in 2.26
    series.
  + Add new API to remove a filter from an user content manager
    given its identifier.
  + Add support for HSTS.
  + Several improvements and bug fixes in MSE media player.
  + Fix building without unified sources.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Fri Aug 30 2019 bjorn.lie@gmail.com
- Disable pkgconfig(wpe-1.0) and pkgconfig(wpebackend-fdo-1.0)
  BuildRequires and pass DUSE_WPE_RENDERER=OFF to cmake. Needs more
  work upstream.
* Fri Aug 30 2019 bjorn.lie@gmail.com
- Update to version 2.25.4:
  + Switch to use libsoup WebSockets API.
  + Add support for permessage-deflate WebSocket extension.
  + Add support for datalist element in text input fields.
  + Fix a crash with empty video source.
  + Fix several crashes and rendering issues.
* Fri Aug 30 2019 bjorn.lie@gmail.com
- Update to version 2.25.3:
  + Remove support for GTK2 NPAPI plugins.
  + Fix web view updates after swapping web process if accelerated
    compositing mode is forced.
  + Make kinetic scrolling work again.
  + Fix position of emoji chooser when page is scrolled.
  + Fix web process deadlock when scrolling twitter timeline which
    contains HLS videos.
  + Make navigation gesture use dark fallback background color
    color on dark themes.
  + Make Previous/Next gesture work in RTL mode.
  + Support cancelling touchscreen back/forward gesture.
  + Add user agent quirk to make github work in FreeBSD.
  + Fix content disappearing when using CSS transforms.
  + Fix some radio streams that could not be played.
  + Fix video pause that sometimes caused to skip to finish.
  + Fix volume level changes when playing a video.
  + Fix several crashes and rendering issues.
- Changes from version 2.25.2:
  + Enable process switch on cross site navigation.
  + Use libwpe with fdo backend to implement accelerated
    compositing under wayland.
  + Fix rendering artifacts in youtube volume button.
  + Fix trapezoid artifact in github comment box.
  + Ensure web extensions directory is readable when sandbox is
    enabled.
  + Fix the executable name of WebDriver process, renamed by
    mistake in 2.25.1.
  + Enable hyperlink auditing setting by default.
  + Remove the option to build without using the redirected
    XComposite window.
  + Fix HLS streams being slow to start.
  + Make accessibility work when sandbox is enabled.
  + Fix several crashes and rendering issues.
- Changes from version 2.25.1:
  + Add support for subprocess sandboxing.
  + Add API to get the web process unique identifier of a
    WebKitFrame.
  + Add WebKitWebPage::did-associate-form-controls-for-frame signal
    and deprecate did-associate-form-controls.
  + Implement AtkComponentIface scroll_to methods.
  + Improve rendering of form controls when GTK theme is dark and
    enable prefers-color-scheme media query.
  + Show the emoji chooser popover for editable content.
  + Fix touch capabilities detection for websites checking touch
    events properties present in window or pointer media queries.
  + Fix several crashes and rendering issues.
- Drop webkit2gtk3-bwo197558-hang.patch: Fixed upstream.
- Add pkgconfig(wpe-1.0) and pkgconfig(wpebackend-fdo-1.0)
  BuildRequires: New dependencies.
- Enable bubblewrap, xdg-dbus-proxy and pkgconfig(libseccomp)
  BuildRequires as well as bubblewrap and xdg-dbus-proxy Requires:
  Sandbox feature is enabled again.
- Drop conditional pkgconfig(gtk+-2.0) BuildRequires and
  webkit2gtk3-plugin-process-gtk2 sub-package, support for gtk2
  plugins are now dropped upstream. Add Obsoletes in libwebkit2gtk.
* Wed Aug 28 2019 bjorn.lie@gmail.com
- Update to version 2.24.4 (boo#1148931):
  + Updated the user agent string to make happy certain websites
    which would claim that the browser being used was unsupported.
  + Improve loading of multimedia streams to avoid memory
    exhaustion due to excessive caching.
  + Fix display of documents with MIME type application/xml in the
    Web Inspector, when loaded using XmlHttpRequest.
  + Fix a hang while scrolling certain websites which include HLS
    video content (Twitter, for example).
  + Fix rounding artifacts in volume levels for media playback.
  + Fix several crashes and rendering issues.
  + Fix the build with video track support disabled.
  + Fix the build with OpenGL support disabled.
  + Fix build issue which would cause media controls to disappear
    when Python 3.x was used during the build process.
  + Security fixes: CVE-2019-8644, CVE-2019-8649, CVE-2019-8658,
    CVE-2019-8669, CVE-2019-8678, CVE-2019-8680, CVE-2019-8683,
    CVE-2019-8684, CVE-2019-8688, CVE-2019-8674, CVE-2019-8707,
    CVE-2019-8719, CVE-2019-8733, CVE-2019-8763, CVE-2019-8765,
    CVE-2019-8821, CVE-2019-8822.
- Drop webkit2gtk3-bwo197558-hang.patch: Fixed upstream.
* Sun Jul 14 2019 rcoe@wi.rr.com
- Add webkit2gtk3-bwo197558-hang.patch for hang (bwo#197558)
* Mon Jul  8 2019 mgorse@suse.com
- Drop webkit2gtk3-boo1088932-a11y-state-set.patch: fixed upstream.
* Tue Jul  2 2019 bjorn.lie@gmail.com
- Update to version 2.24.3:
  + Deprecate WebSQL APIs.
  + Make Previous/Next gesture work in RTL mode.
  + Fix content disappearing when using CSS transforms.
  + Fix rendering artifacts in youtube volume button.
  + Fix trapezoid artifact in github comment box.
  + Fix video pause that sometimes caused to skip to finish.
  + Fix volume level changes when playing a video.
  + Fix HLS streams being slow to start.
  + Fix some radio streams that could not be played.
  + Fix the build with older versions of GStreamer.
  + Fix the build with video and audio disabled.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2019-8666, CVE-2019-8673, CVE-2019-8676,
    CVE-2019-8681, CVE-2019-8687, CVE-2019-8689, CVE-2019-8690,
    CVE-2019-8726.
  + Updated translations.
- Drop upstream fixed patches:
  + webkit2gtk3-bug196440-build-fix.patch.
  + webkit2gtk3-bug198080-build-fix.patch.
* Sat Jun 22 2019 mgorse@suse.com
- Add webkit2gtk3-bug196440-build-fix.patch and
  webkit2gtk3-bug198080-build-fix.patch: fix build failures on
  SLE/Leap 15 and SLE 12.
* Fri May 24 2019 bjorn.lie@gmail.com
- Update to version 2.24.2 (boo#1135715):
  + Fix rendering of emojis copy-pasted from GTK emoji chooser.
  + Fix space characters not being rendered with some CJK fonts.
  + Fix adaptive streaming playback with older GStreamer versions.
  + Set a maximum zoom level for pinch zooming gesture.
  + Fix navigation gesture to not interfere with scrolling.
  + Fix SSE2 detection at compile time, ensuring the right flags
    are passed to the compiler.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2019-8595, CVE-2019-8607, CVE-2019-8615,
    CVE-2019-8671, CVE-2019-8672, CVE-2019-8677, CVE-2019-8679,
    CVE-2019-8686, CVE-2019-8735.
  + Updated translations.
- Drop webkit2gtk3-fix-i586-build.patch: Fixed upstream.
* Wed Apr 24 2019 mliska@suse.cz
- Disable LTO (boo#1133291).
* Mon Apr 15 2019 dimstar@opensuse.org
- Add webkit2gtk3-fix-i586-build.patch: Fix build on i586.
* Wed Apr 10 2019 bjorn.lie@gmail.com
- Update to version 2.24.1 (boo#1132256):
  + Do not allow changes in active URI before provisional load
    starts for non-API requests.
  + Stop the threaded compositor when the page is not visible or
    layer tree state is frozen.
  + Use WebKit HTTP source element again for adaptive streaming
    fragments downloading.
  + Properly handle empty resources in
    webkit_web_resource_get_data().
  + Add quirk to ensure outlook.live.com uses the modern UI.
  + Fix methods returing GObject or boxed types in JavaScriptCore
    GLib API.
  + Ensure callback data is passed to functions and constructors
    with no parameters in JavaScriptCore GLib API.
  + Fix rendering of complex text when the font uses x,y origins.
  + Fix sound loop with Google Hangouts and WhatsApp notifications.
  + Fix the build with GStreamer 1.12.5 and GST GL enabled.
  + Detect SSE2 at compile time.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2019-6251, CVE-2019-11070.
- Drop webkitgtk-gstreamer-gl-build-fix.patch: Fixed upstream.
* Tue Mar 26 2019 mgorse@suse.com
- Add webkitgtk-gstreamer-gl-build-fix.patch: fix build on
  SLE/Leap 15 (webkit#196178).
* Tue Mar 19 2019 mgorse@suse.com
- Disable openjpeg on SLE 12. Our version isn't new enough.
* Wed Mar 13 2019 bjorn.lie@gmail.com
- Update to version 2.24.0:
  + Added support fot content filtering.
  + Variation fonts support.
  + Fully emoji rendering support.
  + Added navigation and pinch zoom gestures for touchpads.
  + Support for JPEG2000 images.
  + Script dialogs are now modal to the current web view only.
  + New API to convert URI to format for display.
  + Security fixes: CVE-2019-8375 (boo#1126768), CVE-2019-8506,
    CVE-2019-8524, CVE-2019-8535, CVE-2019-8536, CVE-2019-8544,
    CVE-2019-8551, CVE-2019-8558, CVE-2019-8559, CVE-2019-8563,
    CVE-2019-8768.
* Wed Mar  6 2019 bjorn.lie@gmail.com
- Update to version 2.23.92:
  + Fix constructors returning a GObject in JSC GLib API.
  + Do not scan NPAPI plugins when plugins are disabled in
    settings.
  + Add WebKitUserContentFilterStore to the API docs.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Sun Mar  3 2019 bjorn.lie@gmail.com
- Update to version 2.23.91:
  + Add new API to handle user content filters.
  + Fix a UI process crash while filling selection data during drag
    and drop.
  + Fix deadlock on Linux/x64 between SamplingProfiler and VMTraps.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Sun Mar  3 2019 bjorn.lie@gmail.com
- Update to version 2.23.90:
  + Add a new setting to disable JavaScript elments from documents
    during parsing.
  + Add new API to expose JavaScriptCore options.
  + Add support for JPEG2000 images.
  + Add support for back/forward touchpad gesture.
  + Add support for pinch zoom on touchpad.
  + Use a scrolled window in alert dialogs to handle long contents.
  + Sleep disabler now inhibits idle when a "System" sleep disabler
    is requested.
  + Remove experimental sandboxing support, it's not yet ready for
    stable release.
  + Fix a web process deadlock when starting the remote inspector.
  + Fix a crash when browsing inspector:// URI without port set.
  + Fix several crashes and rendering issues.
- Add openjpeg2 and openjpeg2-devel BuildRequires: New
  dependencies.
- Drop webkit2gtk3-python3.patch: Not needed anymore.
- Disable bubblewrap, xdg-dbus-proxy and pkgconfig(libseccomp)
  BuildRequires and bubblewrap, xdg-dbus-proxy Requires: Sandbox
  support was disabled by upstream again.
- Stop passing -DENABLE_ACCELERATED_2D_CANVAS=ON to cmake, follow
  upstream default.
* Sun Mar  3 2019 bjorn.lie@gmail.com
- Update to version 2.23.3:
  + Fix rendering of emoji sequences containing zero with joiner.
  + Fallback to a colored font when rendering emojis.
  + Fix rendering artifacts on Youtube while scrolling under X11.
  + Remove DConf permissions from sandbox.
  + Fix build from release tarball with gtkdoc enabled.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Sun Mar  3 2019 bjorn.lie@gmail.com
- Update to version 2.23.2:
  + Fix rendering artifacts in some websites with accelerated
    compositing enabled.
  + Add initial support for variation fonts.
  + Add new API to convert a URI to a format for display.
  + Make scrollbars follow gtk-primary-button-warps-slider setting.
  + Fix crashes when closing the WebDriver session.
  + Fix the build with OpenGL disabled.
  + Fix several crashes and rendering issues.
- Changes from version 2.23.1:
  + Add initial support for subprocess sandboxing in Linux.
  + Add new permission request type for media device information.
  + Make scrollbars follow gtk-primary-button-warps-slider setting.
  + Script dialogs are now modal to the current web view only.
  + Fix several crashes and rendering issues.
- Add bubblewrap, xdg-dbus-proxy and pkgconfig(libseccomp)
  BuildRequires: New dependencies for subprocess sandboxing.
- Add bubblewrap and xdg-dbus-proxy Requires: They are needed at
  runtime.
- Disable webkit2gtk3-python3.patch: Needs rebase or possibly
  outright dropping as fixed, as some parts of them are checked in
  upstream.
* Sat Mar  2 2019 bjorn.lie@gmail.com
- Update to version 2.22.7:
  + Fix rendering of glyphs in Hebrew (and possibly other
    languages) when Unicode NFC normalization is used.
  + Fix several crashes and race conditions.
  + Security fixes: CVE-2019-8518, CVE-2019-8523.
* Wed Feb 13 2019 mgorse@suse.com
- Replace webkit2gtk3-boo1088932-a11y-state-set.patch with a patch
  proposed for webkit#188599. The original patch didn't always
  prevent crashes.
* Sat Feb  9 2019 bjorn.lie@gmail.com
- Update to version 2.22.6 (boo#1124937):
  + Make kinetic scrolling slow down smoothly when reaching the
    ends of pages, instead of abruptly, to better match the GTK+
    behaviour.
  + Fix Web inspector magnifier under Wayland.
  + Fix garbled rendering of some websites (e.g. YouTube) while
    scrolling under X11.
  + Fix several crashes, race conditions, and rendering issues.
- CVE identifiers fixed: CVE-2019-6212, CVE-2019-6215,
  CVE-2019-6216, CVE-2019-6217, CVE-2019-6226, CVE-2019-6227,
  CVE-2019-6229, CVE-2019-6233, CVE-2019-6234, CVE-2019-6201,
  CVE-2019-7285, CVE-2019-7292, CVE-2019-8503, CVE-2019-8515.
* Wed Dec 26 2018 bjorn.lie@gmail.com
- Pass DENABLE_ACCELERATED_2D_CANVAS=ON to cmake, build accelerated
  2d canvas support, we already build the needed support in cairo.
- Switch to Ninja build, add ninja BuildRequires and pass GNinja to
  cmake and use ninja_build and ninja_make macros.
* Wed Dec 26 2018 schwab@suse.de
- Don't use gold on ppc.
* Mon Dec 17 2018 bjorn.lie@gmail.com
- Update to version 2.22.5:
  + Improved the logic to determine for which architectures to
    enable the JIT compiler support and USE_SYSTEM_MALLOC at build
    time.
  + Fix the build with ENABLE_VIDEO=OFF and ENABLE_OPENGL=OFF.
  + Fix several crashes.
  + Security fixes: CVE-2018-4437 (boo#1119553), CVE-2018-4438
    (boo#1119554), CVE-2018-4441 (boo#1119555), CVE-2018-4442
    (boo#1119556), CVE-2018-4443 (boo#1119557), CVE-2018-4464
    (boo#1119558).
* Fri Dec  7 2018 mgorse@suse.com
- Disable media source extension on SLE/Leap 15 and earlier, since
  it requires gstreamer 1.14.0.
* Wed Nov 28 2018 schwab@suse.de
- Reduce memory constraints for riscv64
* Thu Nov 22 2018 bjorn.lie@gmail.com
- Update to version 2.22.4 (boo#1116998):
  + Expose ENABLE_MEDIA_SOURCE as a public build option.
  + Fix a crash when using Cairo versions between 1.15 and 1.16.0
  + Fix the build with -DLOG_DISABLED=0.
  + Fix the build with ENABLE_VIDEO=OFF and ENABLE_WEB_AUDIO=OFF.
  + Fix debug builds of JavaScriptCore.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2018-4372.
* Mon Nov 12 2018 guillaume.gardet@opensuse.org
- Update _constraints to latest values to avoid OOM erros
* Mon Oct 29 2018 bjorn.lie@gmail.com
- Update to version 2.22.3:
  + Many improvements and fixes for video playback with media
    source extensions (MSE), which improve the user experience
    across the board, and in particular for playback of WebM
    videos.
  + Fix a memory leak during media playback when using playbin3.
  + Fix portions of Web views not being rendered after resizing.
  + Fix Resource Timing reporting for <iframe> elements.
  + Fix the build with the remote Web Inspector disabled.
  + Fix the build on ARMv7 with NEON extensions.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2018-4345, CVE-2018-4386.
* Thu Oct 11 2018 mgorse@suse.com
- Re-enable building with python 3 for SLE/Leap 15 and Tumbleweed
- Update webkit2gtk3-python3.patch.
* Thu Oct  4 2018 mgorse@suse.com
- Integrate changes needed for SLE 12 / leap 42.3:
  + depend on gcc7-c++, and pass appropriate executables to cmake.
  + Disable web crypto API: libgcrypt is too old.
  + Define USE_GSTREAMER_GL=FALSE: needs gstreamer 1.10.0 or newer.
- disable libwoff2 for SLE 15/12 and Leap 15/42.3, since it is not
  available there.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 2.22.2:
  + Several fixes for video playback with media source extensions
    (MSE). This allows using WebM support for YouTube, which no
    longer works through regular video source. Note that MSE is
    still disabled by default and
    webkit_settings_set_enable_mediasource() has to be used to
    enable the feature.
  + Fix the build when only Wayland support is enabled and X11
    headers are not available.
- Changes from version 2.22.1:
  + Fix printing in landscape.
  + Fix the build in several platforms: s390x, ppc64le, armv7hl.
  + Fix the build with a11y disabled.
  + Fix the build with video disabled.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2018-4375, CVE-2018-4376, CVE-2018-4378,
    CVE-2018-4382, CVE-2018-4392, CVE-2018-4416.
- Add new upstream maintainer's GPG key to the keyring.
* Tue Sep  4 2018 bjorn.lie@gmail.com
- Update to version 2.22.0 (boo#1110279):
  + New JavaScriptCore GLib API.
  + Switched to use complex text code path unconditionally.
  + Added playbin3 support to GStreamer media backend.
  + Support for WebDriver advance user insteraction commands.
  + Default option menu implementation now uses a GtkTreeView.
  + Security fixes: CVE-2018-4191, CVE-2018-4197, CVE-2018-4299,
    CVE-2018-4306, CVE-2018-4309, CVE-2018-4312, CVE-2018-4314,
    CVE-2018-4315, CVE-2018-4316, CVE-2018-4317, CVE-2018-4318,
    CVE-2018-4319, CVE-2018-4323, CVE-2018-4328, CVE-2018-4358,
    CVE-2018-4359, CVE-2018-4361, CVE-2018-4373.
* Fri Aug 24 2018 bjorn.lie@gmail.com
- Update to version 2.21.92:
  + Add new API to inject/register user content in isolated worlds.
  + Add more API to JSCException to handle column number, convert
    exception to string, get the exception backtrace, create
    exceptions with a custom error name and report exception
    message with full details.
  + Fix excessive CPU usage when getting the process memory
    footprint.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Thu Aug 16 2018 bjorn.lie@gmail.com
- Update to version 2.21.91:
  + Add enable-media-capabilities setting.
  + Stop pushing buffers when seeking status changes in media
    player.
  + Fix rendering of theme styled buttons.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Add explict pkgconfig(gstreamer-app-1.0),
  pkgconfig(gstreamer-audio-1.0),
  pkgconfig(gstreamer-codecparsers-1.0),
  pkgconfig(gstreamer-fft-1.0), pkgconfig(gstreamer-mpegts-1.0),
  pkgconfig(gstreamer-pbutils-1.0), pkgconfig(gstreamer-tag-1.0)
  and pkgconfig(gstreamer-video-1.0) BuildRequires: align with what
  configure checks for.
- Disable webkit2gtk3-python3.patch via bcond_with: Patch currently
  breaks the build.
* Mon Aug 13 2018 bjorn.lie@gmail.com
- Update to version 2.20.5:
  + Fix rendering artifacts in some web sites due to a bug
    introduced in 2.20.4.
* Wed Aug  8 2018 bjorn.lie@gmail.com
- Update to version 2.21.5:
  + Add API to evaluate code in a new object to JavaScriptCore GLib
    API.
  + Add API to check for syntax errors in given code to
    JavaScriptCore GLib API.
  + Update jsc_context_evaluate_with_source_uri() to receive also a
    starting line number.
  + Add API to allow creating variadic functions to JavaScriptCore
    GLib API.
  + Add –host option to WebDriver process.
  + Handle acceptInsecureCertificates capability in WebDriver.
  + Fix video freezes when GStreamerGL is not installed.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Refresh webkit2gtk3-boo1088932-a11y-state-set.patch and
  webkit2gtk3-python3.patch with quilt.
* Wed Aug  8 2018 bjorn.lie@gmail.com
- Update to version 2.21.4:
  + Switch to use a popup window with a tree view instead of a menu
    for option menu default implementation.
  + Add API to run javascript from a WebKitWebView in an isolated
    world.
  + Fix UI process crash in WebKitFaviconDatabase when pageURL is
    unset.
  + Fix several crashes and rendering issues.
* Wed Aug  8 2018 luc14n0@linuxmail.org
- Update to version 2.21.3:
  + Ensure memory monitor properly notifies all child processes.
  + Add maximize, minimize and fullscreen window commands to
    WebDriver.
  + Fix a network process crash when trying to get cookies of
    about:blank page.
  + Fix UI process crash when closing the window under Wayland.
  + Disable Gigacage if mmap fails to allocate in Linux.
  + Fix several crashes and rendering issues.
- Changes from version 2.21.2:
  + Remove resource load statistics API, it's not ready yet.
  + Add initial implementation of WebDriver advance user
    insteraction commands.
  + Add introspectable alternatives for functions using vargars to
    JavaScriptCore GLib API.
  + Implement MouseEvent.buttons.
  + Fix downloads started by context menu failing in some websites
    due to missing user agent HTTP header.
- Rebase webkit2gtk3-python3.patch generate-bytecode-files chunks.
* Wed Aug  8 2018 luc14n0@linuxmail.org
- Update to version 2.21.1:
  + Add initial JavaScriptCore GLib API.
  + Use JavaScriptCore GLib API in WebKit layer and deprecate most
    of the DOM bindings API as well as
  + methods using the JavaScriptCore C API.
  + Switch to use complex text code path unconditionally.
  + Properly close the connection to the Wayland nested compositor
    in the WebProcess.
  + Add playbin3 support to GStreamer media backend.
  + Fix a deadlock when destroying the media player in non
    accelerated compositing mode.
- Drop webkitgtk-typelib-sharelib-link.patch: there is no
  JavaScriptCore.gir.in file to be patched anymore.
* Tue Aug  7 2018 bjorn.lie@gmail.com
- Update to version 2.20.4:
  + Fix a crash when leaving accelerated compositing mode.
  + Fix non-deterministic build failure due to missing
    JavaScriptCore/JSContextRef.h.
  + Security fixes: CVE-2018-4261, CVE-2018-4262, CVE-2018-4263,
    CVE-2018-4264, CVE-2018-4265, CVE-2018-4266, CVE-2018-4267,
    CVE-2018-4270, CVE-2018-4272, CVE-2018-4273, CVE-2018-4278,
    CVE-2018-4284.
- Drop webkit2gtk3-boo1101999-off-by-one.patch: Fixed upstream.
* Fri Jul 20 2018 mgorse@suse.com
- Add webkit2gtk3-boo1101999-off-by-one.patch: fix off-by-one in
  xdg_mime_get_simple_globs (boo#1101999 CVE-2018-12911).
* Mon Jun 11 2018 bjorn.lie@gmail.com
- Update to version 2.20.3:
  + Fix installation directory of API documentation.
  + Disable Gigacage if mmap fails to allocate in Linux.
  + Add user agent quirk for paypal website.
  + Properly detect compiler flags, needed libs, and fallbacks for
    usage of 64-bit atomic operations.
  + Fix a network process crash when trying to get cookies of
    about:blank page.
  + Fix UI process crash when closing the window under Wayland.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2018-4190, CVE-2018-4199, CVE-2018-4218,
    CVE-2018-4222, CVE-2018-4232, CVE-2018-4233, CVE-2018-4246,
    CVE-2018-11646.
- Drop webkit2gtk3-boo1095611-null-page-url.patch: Fixed upstream.
* Fri Jun  8 2018 mgorse@suse.com
- Add webkit2gtk3-boo1095611-null-page-url.patch: don't crash if
  the page URL is null (CVE-2018-11646).
* Mon May 14 2018 bjorn.lie@gmail.com
- Split out the MiniBrowser in own sub-package, there might be
  users who just want to test it without having to pull all of the
  builddependencies.
* Tue May  8 2018 schwab@suse.de
- Disable JIT on riscv64
* Mon May  7 2018 bjorn.lie@gmail.com
- Update to version 2.20.2:
  + Do TLS error checking on GTlsConnection::accept-certificate to
    finish the load earlier in case of errors.
  + Properly close the connection to the nested wayland compositor
    in the Web Process.
  + Avoid painting backing stores for zero-opacity layers.
  + Fix downloads started by context menu failing in some websites
    due to missing user agent HTTP header.
  + Fix video unpause when GStreamerGL is disabled.
  + Fix several GObject introspection annotations.
  + Update user agent quiks to fix Outlook.com and Chase.com.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2018-4200 (boo#1092280), CVE-2018-11712
    (boo#1096061).
* Tue May  1 2018 bjorn.lie@gmail.com
- Enable pkgconfig(libbrotlidec), and add pkgconfig(libwoff2dec)
  BuildRequires and no longer pass -DUSE_WOFF2=false to cmake.
  Woff2 is now available in openSUSE.
- Pass -DENABLE_MINIBROWSER=ON to cmake, build the MiniBrowser and
  package it in devel subpackage. Usefull for developers.
* Wed Apr 11 2018 mgorse@suse.com
- Add webkit2gtk3-boo1088932-a11y-state-set.patch: fix crash when
  atk_object_ref_state_set is called on an AtkObject that's being
  destroyed (boo#1088932 webkit#184366).
* Tue Apr 10 2018 bjorn.lie@gmail.com
- Update to version 2.20.1:
  + Improve error message when Gigacage cannot allocate virtual
    memory.
  + Add missing WebKitWebProcessEnumTypes.h to
    webkit-web-extension.h.
  + Improve web process memory monitor thresholds.
  + Fix a web process crash when the web view is created and
    destroyed quickly.
  + Fix a network process crash when load is cancelled while
    searching for stored HTTP auth credentials.
  + Fix the build when ENABLE_VIDEO, ENABLE_WEB_AUDIO and
    ENABLE_XSLT are disabled.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2018-4204.
  + Updated translations.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 2.20.0 (boo#1088182):
  + New API to retrieve and delete cookies with
    WebKitCookieManager.
  + New web process API to detect when form is submitted via
    JavaScript.
  + Several improvements and fixes in the touch/gestures support.
  + Support for the “system” CSS font family.
  + Complex text rendering improvements and fixes.
  + Added a low power mode.
  + More complete and spec compliant WebDriver implementation.
  + Security fixes: CVE-2018-4101, CVE-2018-4113, CVE-2018-4114,
    CVE-2018-4117, CVE-2018-4118, CVE-2018-4119,
    CVE-2018-4120, CVE-2018-4122, CVE-2018-4125,
    CVE-2018-4127, CVE-2018-4128, CVE-2018-4129,
    CVE-2018-4133, CVE-2018-4146, CVE-2018-4161,
    CVE-2018-4162, CVE-2018-4163, CVE-2018-4165, CVE-2018-11713,
    CVE-2018-4207, CVE-2018-4208, CVE-2018-4209, CVE-2018-4210,
    CVE-2018-4212, CVE-2018-4213.
* Tue Mar  6 2018 mgorse@suse.com
- Add webkit2gtk3-python3.patch: port to python 3 (bsc#1079812,
  webkit#156674).
- Add conditional to optionally require python3, rather than
  python2 + python-xml, and adjust %%build to use python3.
* Tue Mar  6 2018 bjorn.lie@gmail.com
- Update to version 2.19.92:
  + Ensure DNS prefetching cannot be re-enabled if disabled by
    settings.
  + Fix seek sometimes not working.
  + Fix rendering of emojis that were using the wrong scale factor
    in some cases.
  + Fix rendering of combining enclosed keycap.
  + Fix rendering scale of some layers in HiDPI.
  + Fix a crash in Wayland when closing the web view.
  + Fix crashes upower crashes when running inside a chroot or on
    systems with broken dbus/upower.
  + Fix memory leaks in GStreamer media backend when using
    GStreamer 1.14.
  + Fix the build with Enchant 2.x.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Replace pkgconfig(enchant) with enchant-devel BuildRequires:
  Allow webkit2gtk3 to build with whatever enchant is available in
  target distro.
* Mon Mar  5 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Mar  5 2018 bjorn.lie@gmail.com
- Update to version 2.19.91:
  + Add ENABLE_ADDRESS_SANITIZER to make it easier to build with
    asan support.
  + Fix a crash a under Wayland when using mesa software
    rasterization.
  + Make fullscreen video work again.
  + Fix handling of missing GStreamer elements.
  + Fix rendering when webm video is played twice.
  + Fix kinetic scrolling sometimes jumping around.
  + Fix build with ICU configured without collation support.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Do a minor spec cleanup.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 2.19.90:
  + WebSockets use system proxy settings now (requires libsoup
    2.61.90).
  + Show the context menu on long-press gesture.
  + Add support for Shift + mouse scroll to scroll horizontally.
  + Fix zoom gesture to actually zoom instead of changing the page
    scale.
  + Implement support for Graphics ARIA roles.
  + Make sleep inhibitors work under Flatpak.
  + Add get element CSS value command to WebDriver.
  + Fix a crash aftter a swipe gesture.
  + Fix several crashes and rendering issues.
- Drop webkit2gtk3-fix-wayland-crash.patch: fixed upstream.
* Mon Mar  5 2018 bjorn.lie@gmail.com
- Update to version 2.19.6:
  + Fix crashes due to duplicated symbols in libjavascriptcoregtk
    and libwebkit2gtk.
  + Fix parsing of timeout values in WebDriver.
  + Implement get timeouts command in WebDriver.
  + Fix deadlock in GStreamer video sink during shutdown when
    accelerated compositing is disabled.
  + Fix several crashes and rendering issues.
* Mon Mar  5 2018 zaitor@opensuse.org
- Update to version 2.19.5:
  + This is a follow up release to export
    webkit_dom_dom_window_webkit_message_handlers_post_message()
    symbol that was hidden in 2.19.4 by mistake.
- Changes from version 2.19.4:
  + Add web process API to detect when form is submitted via
    JavaScript.
  + Add new API to replace
    webkit_form_submission_request_get_text_fields() that is now
    deprecated.
  + Add WebKitWebView::web-process-terminated signal and deprecate
    web-process-crashed.
  + Fix rendering issues when editing text areas.
  + Use FastMalloc based GstAllocator for GStreamer.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Mon Mar  5 2018 dimstar@opensuse.org
- Apply -DUSE_SYSTEM_MALLOC=ON unconditionally in all builds
  (bmalloc seems to be exhausting memory on run time).
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 2.19.3:
  + Fix web process crash at startup in bmalloc.
  + Fix several memory leaks in GStreamer media backend.
  + WebKitWebDriver process no longer links to
    libjavascriptcoregtk.
  - Fix several crashes and rendering issues.
- Changes from version 2.19.2:
  + Add new API to add, retrieve and delete cookies via
    WebKitCookieManager.
  + Add functions to WebSettings to convert font sizes between
    points and pixels.
  + Ensure cookie operations take effect when they happen before a
    web process has been spawned.
  + Automatically adjust font size when GtkSettings:gtk-xft-dpi
    changes.
  + Fix several crashes and rendering issues.
* Mon Mar  5 2018 dimstar@opensuse.org
- Allow OBS service to verify the tarball signature:
  + Add webkit2gtk3.keyring: Carlos Garcia Campos' public key.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 2.19.1:
  + Add initial resource load statistics support.
  + Add API to expose availability of certain editing commands in
    WebKitEditorState.
  + Add API to query whether a WebKitNavigationAction is a redirect
    or not.
  + Improve complex text rendering.
  + Add support for the "system" CSS font family.
  + Implement low power mode.
  + Fix several crashes and rendering issues.
- Drop webkit2gtk3-no-return-in-nonvoid.patch: fixed upstream.
- Add pkgconfig(libbrotlidec) and pkgconfig(upower-glib)
  BuildRequires: new dependencies.
* Fri Mar  2 2018 fcrozat@suse.com
- Add webkit2gtk3-fix-wayland-crash.patch: fix crash when using
  Wayland with QXL/virtio (bsc#1079512, webkit#182490).
* Thu Mar  1 2018 dimstar@opensuse.org
- Add missing dependencies from the -devel package to the build
  typelib-1_0-*: just like libraries, a consumer of the devel
  package can assume the typelibs to be present:
  + typelib-1_0-WebKit2-%%{_sonameverpkg}.
  + typelib-1_0-WebKit2WebExtension-%%{_sonameverpkg}.
* Tue Jan 30 2018 ro@suse.de
- even on recent codestreams there is no binutils gold on s390
  only on s390x.
* Wed Jan 24 2018 bjorn.lie@gmail.com
- Update to version 2.18.6:
  + Fix deadlock in GStreamer video sink during shutdown when
    accelerated compositing is disabled.
  + Several fixes and improvements in WebDriver.
  + Security fixes: CVE-2018-4088, CVE-2017-13885, CVE-2017-7165,
    CVE-2017-13884, CVE-2017-7160, CVE-2017-7153, CVE-2017-7153,
    CVE-2017-7161, CVE-2018-4096.
* Wed Jan 10 2018 zaitor@opensuse.org
- Update to version 2.18.5:
  + Disable SharedArrayBuffers from Web API.
  + Reduce the precision of “high” resolution time to 1ms.
  + Fix API documentation generation with newer gtk-doc.
  + bsc#1075419 - Security fixes: includes improvements to mitigate
    the effects of Spectre (CVE-2017-5753 and CVE-2017-5715).
* Wed Dec 27 2017 jengelh@inai.de
- Update package descriptions.
* Tue Dec 19 2017 zaitor@opensuse.org
- Update to version 2.18.4:
  + Make WebDriver implementation more spec compliant.
  + Fix a bug when trying to remove cookies before a web process is
    spawned.
  + WebKitWebDriver process no longer links to
    libjavascriptcoregtk.
  + Fix several memory leaks in GStreamer media backend.
  + bsc#1073654 - Security fixes: CVE-2017-13866, CVE-2017-13870,
    CVE-2017-7156, CVE-2017-13856.
* Tue Dec  5 2017 dimstar@opensuse.org
- Explicitly buildrequire python2-xml: the build system is (for
  now) hard locked on python2 and relies on the presence of
  python2-xml (used to be pulled in by glib2-devel in the past).
* Fri Nov 10 2017 luc14n0@linuxmail.org
- Update to version 2.18.3:
  + Improve calculation of font metrics to prevent scrollbars from
    being shown unnecessarily in some cases.
  + Fix handling of null capabilities in WebDriver implementation.
  + bsc#1069925 - Security fixes: CVE-2017-13798, CVE-2017-13788,
    CVE-2017-13803.
* Fri Oct 27 2017 idonmez@suse.com
- Update to version 2.18.2:
  + Fix rendering of arabic text.
  + Fix a crash in the web process when decoding GIF images.
  + Fix rendering of wind in Windy.com.
  + Fix several crashes and rendering issues.
* Fri Oct 27 2017 idonmez@suse.com
- Update to version 2.18.1:
  + Improve performance of GIF animations.
  + Fix garbled display in GMail.
  + Fix rendering of several material design icons when using the
    web font.
  + Fix flickering when resizing the window in Wayland.
  + Prevent default kerberos authentication credentials from being
    used in ephemeral sessions.
  + Fix a crash when webkit_web_resource_get_data() is cancelled.
  + Correctly handle touchmove and touchend events in
    WebKitWebView.
  + Fix the build with enchant 2.1.1.
  + Fix the build in HPPA and Alpha.
  + Fix several crashes and rendering issues.
  + bsc#1066892 - Security fixes: CVE-2017-7081, CVE-2017-7087,
    CVE-2017-7089, CVE-2017-7090, CVE-2017-7091, CVE-2017-7092,
    CVE-2017-7093, CVE-2017-7094, CVE-2017-7095, CVE-2017-7096,
    CVE-2017-7098, CVE-2017-7099, CVE-2017-7100, CVE-2017-7102,
    CVE-2017-7104, CVE-2017-7107, CVE-2017-7109, CVE-2017-7111,
    CVE-2017-7117, CVE-2017-7120, CVE-2017-7142.
  + bsc#1073654 - Security fixes: CVE-2017-7157.
* Tue Oct 24 2017 fcrozat@suse.com
- Enable gold linker on s390/s390x on SLE15/Tumbleweed.
* Thu Sep 14 2017 fezhang@suse.com
- Drop gcc6-c++ build conditionals for SLE12 / Leap42.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 2.18.0:
  + Initial WebDriver support.
  + New remote inspector infrastructure.
  + WebCrypto API support is now enabled by default.
  + GStreamerGL is enabled by default when building with GStreamer
    >= 1.10.
  + Kinetic scrolling support.
  + New API to create a WebKitContextMenuItem from a GAction.
  + New API to allow overriding the popup menu of select elements.
* Thu Sep  7 2017 dimstar@opensuse.org
- Add webkit2gtk3-no-return-in-nonvoid.patch: Fix brp error based
  on "warning: control reaches end of non-void function".
* Mon Sep  4 2017 zaitor@opensuse.org
- Update to version 2.17.92:
  + Improve CPU usage when rendering under Wayland in accelerated
    compositing mode.
  + Improve the memory consumption of the UI process under Wayland.
  + Fix rendering issues in some web sites with accelerated
    compositing enabled.
  + Fix a web process crash when closing the WebView.
  + Initialize libgcrypt in the network process too.
  + Show controls if a video element isn’t allowed to play inline.
  + Add support for cookies and screenshots commands in WebDriver.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Sun Aug 20 2017 zaitor@opensuse.org
- Update to version 2.17.91:
  + Fix proxy HTTP authentication for HTTPS requests.
  + Stop kinetic scrolling when a zero movement is reached.
  + Fix UI process crash when selecting text.
  + Fix UI process crash when loading a favicon.
  + Properly handle WebDriver click command on option elements.
  + Fix web process crash when resizing the window with accelerated
    compositing enabled.
  + Fix crashes in 32 bit systems due to incorrect use of GVariant.
  + Fix several crashes and rendering issues.
* Wed Aug  9 2017 zaitor@opensuse.org
- Update to version 2.17.90:
  + WebCrypto API support is now enabled by default.
  + Add API to provide browser information required by automation.
  + Fix the expiration date of manually added cookies.
  + Add support for alerts in WebDriver.
  + WebKitDatabaseProcess binary has been renamed to
    WebKitStorageProcess.
  + Fix several crashes and rendering issues.
* Wed Jul 26 2017 zaitor@opensuse.org
- Update to version 2.17.5:
  + Add initial implementation of WebDriver.
  + Enable GStreamerGL by default when building with GStreamer >=
    1.10.
  + Fix position of context menu in Wayland.
  + Properly close cookies database at network process exit.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Drop webkit2gtk3-gcc7.patch and
  webkit2gtk3-machine-context.patch: Fixed upstream.
- Add pkgconfig(gstreamer-gl-1.0) BuildRequires: New dependency.
- Add explicit Mesa-libEGL-devel, Mesa-libGL-devel,
  Mesa-libGLESv1_CM-devel, Mesa-libGLESv2-devel and
  Mesa-libGLESv3-devel BuildRequires.
* Mon Jul 24 2017 zaitor@opensuse.org
- Update to version 2.17.4:
  + Add API to allow overriding popup menus.
  + Add kinetic scrolling support.
  + Improve theme rendering performance when using GTK+ >= 3.20.
  + Improve error message when webkit_web_view_run_javascript()
    fails due to a JavaScript exception.
  + Fix artifacts when rendering large images.
  + Fix blob downloads.
  + Fix web process deadlock when seeking youtube videos.
  + Fix alpha premultiplying when using cairo to draw the video
    frames.
  + Fix web process deadlock when closing the remote inspector
    frontend.
  + Update several web inspector icons.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Changes from version 2.17.3:
  + Add new API to create a WebKitContextMenuItem from a GAction.
  + Fix graphics repaint hungs in accelerated compositing mode
    after a resize.
  + Fix rendering glitches in HiDPI in long GitHub Gist pages when
    focusing the comments textarea.
  + Remove Firefox user agent quirk for Google domains.
  + Remove LATEST_RECORD_VERSION from GnuTLS priority string.
  + Improve colors of inspector SVG icons.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Changes from version 2.17.2:
  + Update user agent quirks to make Youtube and new Google login
    page work.
  + Fix URL shown in the title of beforeunload dialogs.
  + Focus first input field of HTTP authentication dialog.
  + Fix rendering of PNG images when decoded in more than one
    chunk.
  + Update several web inspector icons.
  + Fix the build with OpenGL disabled.
  + Fix several crashes and rendering issues.
- Changes from version 2.17.1:
  + Switch to use new remote inspector infraestructure instead of
    legacy Web Sockets based one.
  + Add API to enable and handle Web Automation.
  + Load large images asynchronously off the main theead.
  + Use GtkFileChooserNative for open/save dialogs when available.
  + Make file chooser run as modal by default if possible.
  + Fix position of dropdown menus in Wayland.
  + Keep URI fragments after a server redirection.
  + Implement support for aria-haspopup and aria-autocomplete.
  + Implement aria-value support for focusable separators.
  + Fix playing of some live streams.
- Add webkit2gtk3-gcc7.patch: Fix build with gcc7 (webkit#173544).
- Add webkit2gtk3-machine-context.patch: Fix build for ppc64le
  (webkit#173590).
* Mon Jul 24 2017 zaitor@opensuse.org
- Update to version 2.16.6:
  + Fix rendering of spin buttons with GTK+ >= 3.20 when the entry
    width is too short.
  + Fix the build when Wayland target is enabled and X11 disabled.
  + Fix several crashes and rendering issues.
  + bsc#1050469 - Security fixes: CVE-2017-7039, CVE-2017-7018,
    CVE-2017-7030, CVE-2017-7037, CVE-2017-7034, CVE-2017-7055,
    CVE-2017-7056, CVE-2017-7064, CVE-2017-7061, CVE-2017-7048,
    CVE-2017-7046.
* Tue Jun 27 2017 zaitor@opensuse.org
- Update to version 2.16.5:
  + Fix a web process crash when page finishes loading in several
    web sites.
  + Fix the menu of select elements not showing in some cases under
    Wayland.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 2.16.4 (CVE-2017-2538):
  + Fix web process deadlock when seeking youtube videos.
  + Fix blob downloads.
  + Improve theme rendering performance when using GTK+ >= 3.20.
  + Fix positioning of popup menus in Wayland.
  + Fix several crashes and rendering issues.
  + Security fixes: CVE-2017-2538.
  + bsc#1050469 - Security fixes: CVE-2017-7052.
* Mon May 29 2017 zaitor@opensuse.org
- Add conditional gcc6-c++ BuildRequires and #!BuildIgnore:
  libgcc_s1 and also and pass -DCMAKE_C_COMPILER=gcc-6 and
  - DCMAKE_CXX_COMPILER=g++-6 to cmake for SLE/Leap, so we can fully
  build Webkit2gtk3 without disabling features.
- Drop webkitgtk-disable-gcc-version-checks.patch, no longer needed
  following above changes.
- Remove the compilation flag to disable FTL JIT, no longer needed
  following above changes.
* Thu May 25 2017 zaitor@opensuse.org
- Update to version 2.16.3:
  + Fix URL shown in the title of beforeunload dialogs.
  + Focus first input field of HTTP authentication dialog.
  + Fix rendering glitches in HiDPI in long GitHub Gist pages when
    focusing the comments textarea.
  + Remove Firefox user agent quirk for Google domains.
  + Remove LATEST_RECORD_VERSION from GnuTLS priority string.
  + Fix several crashes and rendering issues.
  + bsc#1050469 - Security fixes: CVE-2017-2496, CVE-2017-2539,
    CVE-2017-2510, CVE-2017-7011, CVE-2017-7040, CVE-2017-7059,
  CVE-2017-1000121, CVE-2017-1000122.
* Tue May 23 2017 dimstar@opensuse.org
- Drop ncurses-devel BuildRequires: this is no longer required.
* Tue May  9 2017 zaitor@opensuse.org
- Update to version 2.16.2:
  + Update user agent quirks to make Youtube and new Google login
    page work.
  + Fix rendering of animated PNGs.
  + Fix playing of some live streams.
  + Update several web inspector icons.
  + Fix the build with NPAPI plugins enabled but X11 disabled.
  + Fix the build with OpenGL disabled.
  + Fix several crashes and rendering issues.
  + bsc#1050469 - Security fixes: CVE-2017-7006, CVE-2017-7012,
    CVE-2017-7019, CVE-2017-7038, CVE-2017-7041, CVE-2017-7042,
    CVE-2017-7043, CVE-2017-7049.
* Wed Apr  5 2017 zaitor@opensuse.org
- Update to version 2.16.1:
  + Fix no-third-party cookies policy in case of redirections.
  + Keep URL fragments after server redirections.
  + Honor GTK+ font settings.
  + Ensure depth and stencil renderbuffers are created on GLESv2.
  + Prevent new navigations from onbeforeunload handler and
    document unload.
  + Disallow beforeunload alerts from web pages users have never
    interacted with.
  + Fix several crashes and rendering issues.
  + bsc#1050469 - Security fixes: CVE-2017-7020.
* Mon Mar 20 2017 zaitor@opensuse.org
- Update to version 2.16.0:
  + Add missing types to WebKitAutocleanups.
  + Updated translations.
* Tue Mar 14 2017 zaitor@opensuse.org
- Update to version 2.15.92:
  + Show the context menu when triggered by the keyboard.
  + Fix web process deadlocks when destroying the media player.
  + Fix web process crashes when loading animated GIFs.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Wed Mar  1 2017 zaitor@opensuse.org
- Update to version 2.15.91:
  + Fix rendering artifacts when resizing the window in accelerated
    compositing mode.
  + Remove flickering when leaving accelerated compositing mode.
  + Fix a web process crash when loading duck duck go.
  + Properly handle copy drag and drop operations.
  + Fix a hang when sending an IPC messages fails because socket
    read buffers are full.
  + Ensure we never try to load GTK2 plugins in Wayland.
  + Fix several crashes and rendering issues.
* Mon Feb 20 2017 dimstar@opensuse.org
- Update to version 2.15.90:
  + Add an API to add a custom tab into the print dialog.
  + Update cookie manager API to properly work with ephemeral
    sessions.
  + Fix rendering issues in long documents with transparent
    background.
  + Handle extended colors in cairo and texture mapper backends.
  + Release unused UpdateAtlas and reduce the tile coverage on
    memory pressure.
  + The media backend now stores preloaded media in /var/tmp
    instead of user cache dir.
  + Fix a deadlock when the media player is destroyed.
  + Fast replay on video hide/unhide on platforms with limited
    video buffer pools.
  + Fix network process crashes when loading custom URI schemes.
  + Fix video rendering when switching to accelerated compositing
    mode.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Drop upstream fixed patches:
  - webkit2gtk3-167785.patch
  - webkit2gtk3-167876.patch
  - webkit2gtk3-167890.patch
  - webkit2gtk3-167929.patch
* Fri Feb 17 2017 dimstar@opensuse.org
- Add webkit2gtk3-167785.patch: Fix build with disabled JIT (such
  as on ppc564le).
* Thu Feb 16 2017 dimstar@opensuse.org
- Add webkit2gtk3-167876.patch, webkit2gtk3-167890.patch and
  webkit2gtk3-167929.patch: fix webkit stalling on loading
  resources over the network.
* Wed Feb 15 2017 zaitor@opensuse.org
- Update to version 2.15.4:
  + Make accelerating compositing mode on-demand again. By default
    it will only be used for websites that require it, saving a lot
    of memory on websites that don’t need it.
  + Add API to manage hardware acceleration policy.
  + Enable CSS Grid Layout by default.
  + Add API to create ephemeral WebViews to replace the legacy
    private browsing setting that is now deprecated.
  + Handle HTTP authentication for downloads having a WebView
    associated.
  + Add API to WebKitWebsiteDataManager to handle websites data.
  + Fix BadDamage X errors happening when resizing the WebView.
  + Fix several crashes and rendering issues.
- Changes from version 2.15.3:
  + Add API to set network proxy settings.
  + Add API to set initial notification permissions.
  + Add WebKitSecurityOrigin to the API.
  + Add tag property to WebKitNotification.
  + Create GLX OpenGL contexts using version 3.2 (core profile)
    when available to reduce the memory consumption on Mesa based
    drivers.
  + Improve memory pressure handler to reduce the CPU usage on
    memory pressure situations.
  + Add support for key and code properties on keyboard events.
  + More user agent string improvements to improve compatibility
    with several websites.
  + Fix network process crashes when loading custom URI schemes.
  + Fix web process crash when closing the web view in X11.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 2.15.2:
  + Add new API to notify about dynamically added forms to Web
    Extensions.
  + Implement selection interface and states for elements
    supporting aria-selected and for menu roles.
  + Expose STATE_SINGLE_LINE and STATE_MULTI_LINE for ARIA
    searchbox role.
  + Enable WebMemorySampler.
  + Downloads started by context menu actions now have a web view
    associated.
  + Fix a network process crash when main resource load is
    converted into a download.
  + Fix several crashes and rendering issues.
- Changes from version 2.15.1:
  + GObject DOM bindings API marked as unstable has been removed.
  + Switch to use GMenu internally in the context menu
    implementation.
  + The network backend now always sniff contents for Downloads.
* Wed Feb 15 2017 zaitor@opensuse.org
- Update to version 2.14.5:
  + Fix rendering of non-accelerated contents with HiDPI.
  + Revert the fix for rendering issues in long documents with
    transparent background because it caused issues in HiDPI.
* Fri Feb 10 2017 zaitor@opensuse.org
- Update to version 2.14.4:
  + Make accelerating compositing mode on-demand again. By default
    it will only be used for websites that require it, saving a lot
    of memory on websites that don’t need it.
  + Fix rendering issues in long documents with transparent
    background.
  + Release unused UpdateAtlas and reduce the tile coverage on
    memory pressure.
  + The media backend now stores preloaded media in /var/tmp
    instead of user cache dir.
  + Make inspector work again when accelerated compositing support
    is disabled.
  + Fix a deadlock when the media player is destroyed.
  + Fix network process crashes when loading custom URI schemes.
  + Fix overlay scrollbars that are over a subframe.
  + Fix a crash in GraphicsContext3D::drawArrays when using OpenGL
    3.2 core profile.
  + Fix BadDamage X errors happening when resizing the WebView.
  + Fix several crashes and rendering issues.
  + bsc#1024749 - Security fixes: CVE-2017-2365, CVE-2017-2366,
    CVE-2017-2373, CVE-2017-2363, CVE-2017-2362, CVE-2017-2350,
    CVE-2017-2350, CVE-2017-2354, CVE-2017-2355, CVE-2017-2356,
    CVE-2017-2371, CVE-2017-2364, CVE-2017-2369.
* Tue Jan 17 2017 zaitor@opensuse.org
- Update to version 2.14.3:
  + Create GLX OpenGL contexts using version 3.2 (core profile)
    when available to reduce the memory consumption on Mesa based
    drivers.
  + Improve memory pressure handler to reduce the CPU usage on
    memory pressure situations.
  + Fix a regression in WebKitWebView title notify signal emission
    that caused the signal to be emitted multiple times.
  + Fix high CPU usage in the web process loading hyphenation
    dictionaries.
  + More user agent string improvements to improve compatibility
    with several websites.
  + Fix web process crash when closing the web view in X11.
  + Fix the build with OpenGL ES2 enabled.
  + Fix several crashes and rendering issues.
  + bsc#1020950 - Security fixes: CVE-2016-7656, CVE-2016-7635,
    CVE-2016-7654, CVE-2016-7639, CVE-2016-7645, CVE-2016-7652,
    CVE-2016-7641, CVE-2016-7632, CVE-2016-7599, CVE-2016-7592,
    CVE-2016-7589, CVE-2016-7623, CVE-2016-7586.
  + Updated translations.
* Tue Nov  8 2016 dimstar@opensuse.org
- Do not recommend the -lang package with a version: it has close
  to no effect anyway, as the solver could simply ignore it to
  find a solution.
* Thu Nov  3 2016 zaitor@opensuse.org
- Update to version 2.14.2:
  + Expose WebKitDOMHTMLInputElement APIs for form autofill in
    unstable DOM API.
  + Properly update WebKitWebView and WebKitWebPage URI properties
    when request is modified by WebKitWebPage:send-request signal.
  + Restore user agent quirk for Yahoo.
  + Dot not leak the default WebKitWebsiteDataManager in
    WebKitWebContext.
  + Use eglGetPlatformDisplay when available instead of
    eglGetDisplay.
  + Avoid strstr() when checking (E)GL extensions.
  + Fix several crashes and rendering issues.
  + Fix the build with ENABLE_OPENGL=OFF and allow to build on
    Wayland without OpenGL again.
  + Updated translations.
* Mon Oct 17 2016 schwab@suse.de
- Disable JIT on armv6 (webkit#141288).
* Wed Oct 12 2016 zaitor@opensuse.org
- Update to version 2.14.1:
  + MiniBrowser and jsc binaries are now installed in pkglibexecdir
    instead of bindir.
  + Improve performance when resizing a window with multiple web
    views in X11.
  + Check whether GDK can use GL before using
    gdk_cairo_draw_from_gl() in Wayland.
  + Updated default UserAgent string for better compatibility.
  + Fix a crash on github.com in
    IntlDateTimeFormat::resolvedOptions when using the C locale.
  + Fix BadDamage X errors when closing the web view in X11.
  + Fix UIProcess crash when using Japanese input method.
  + Fix build with clang due to missing header includes.
  + Fix the build with USE_REDIRECTED_XCOMPOSITE_WINDOW disabled.
  + Fix several crashes and rendering issues.
  + Updated translations.
  + bsc#1020950 - Security fixes: CVE-2016-4692, CVE-2016-7610.
* Tue Sep 20 2016 dimstar@opensuse.org
- Update to version 2.14.0:
  + Use gdk_cairo_draw_from_gl() when possible in Wayland to render
    directly using the GPU in the UI process.
  + Ensure we don't send an empty referrer header after session
    restore.
  + Fix a web process crash in pages using filter animations.
  + Fix main frame scrolling jumps when scrolling acclerated
    subframes.
  + Fix the size of the cairo surface created in the UI process on
    Wayland.
  + Fix memory leak in JavaScriptCore.
  + Fix the build when '.' is not in @INC by default in perl.
  + Updated translations.
  + bsc#1020950 - Security fixes: CVE-2016-4743, CVE-2016-7587,
    CVE-2016-7598.
- Rebase webkitgtk-disable-gcc-version-checks.patch.
* Fri Sep 16 2016 junrrein@gmail.com
- Reintroduce support for Gtk2 plugins like Flash.
  + Add pkgconfig(gtk+-2.0) BuildRequires.
  + No longer pass -DENABLE_PLUGIN_PROCESS_GTK2=OFF to configure.
  + Split the built plugin to it's own sub-package,
    webkit2gtk3-plugin-process-gtk2, and make sure it's excluded
    from the main package.
  + Only apply these changes to openSUSE via conditional.
* Thu Sep 15 2016 zaitor@opensuse.org
- Update to version 2.13.92:
  + Add clipboard support in Wayland.
  + Improve rendering of scrollbars with themes setting a minimum
    width for the scrollbar CSS gadget.
  + Fix another WebProcess crash when the last WebView is
    destroyed.
  + Fix the build with GCC 6.
- Drop webkitgtk-fix-clipboard.patch: Fixed upstream.
* Sat Sep 10 2016 zaitor@opensuse.org
- Add webkitgtk-fix-clipboard.patch: Fix clipboard support in
  wayland (webkit#146574).
* Fri Sep  9 2016 zaitor@opensuse.org
- Update to version 2.13.91:
  + Improve the performance when resizing the WebView with the
    threaded compositor.
  + Do not try to use GL_PACK_ROW_LENGTH when compiling with GLES2,
    since it's not available.
  + Use a different plugins cache file in Wayland and X11.
  + Fix UI process crash visiting sites protected with HTTP auth
    when using GTK+ < 3.14.
  + Fix a WebProcess crash when the last WebView is destroyed.
  + Fix build configure without Wayland support.
  + Fix the build when compiling with Clang.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Tue Sep  6 2016 zaitor@opensuse.org
- Update to version 2.13.90:
  + Add initial implementation of accelerating compositing support
    under Wayland.
  + Fix performance with the modesetting intel driver and DRI3
    enabled.
  + Improved performance when resizing the web view on X11.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Tue Sep  6 2016 zaitor@opensuse.org
- Update to version 2.13.4:
  + Switched to use the threaded compositor. Accelerated
    compositing mode is now always enabled by default and happens
    in a separate thread in the web process.
  + Make web view background colors work in accelerated
    compositing mode.
  + Fix several crashes and rendering issues.
* Tue Sep  6 2016 zaitor@opensuse.org
- Update to version 2.13.3:
  + Fix Web Process deadlocks when loading HLS videos.
  + Make videos work when painted into a canvas when accelerated
    compositing is enabled.
  + Fix flickering with animated GIFs.
  + Fix a Web Process crash when video repaint is requested with
    GStreamer GL enabled.
  + Reduce the amount of file descriptors that the Web Process
    keeps open.
  + Make memory pressure handler work when cgroups are not
    available.
  + Fix several crashes and rendering issues.
* Tue Sep  6 2016 zaitor@opensuse.org
- Update to version 2.13.2:
  + Properly redraw the web view when reparented in force
    compositing mode.
  + Flip the volume control layout in media controls on RTL.
  + Add support for video orientation to the GStreamer media
    backend.
  + Fix several crashes and rendering issues.
* Tue Sep  6 2016 zaitor@opensuse.org
- Update to version 2.13.1:
  + CSS Grid Layout has been unprefixed and can be enabled as an
    experimental feature at runtime.
  + The HTTP disk cache implements speculative resources
    revalidation.
  + Add a new WebKitSetting to allow universal access from file
    URLs.
  + Fix several crashes and rendering issues.
- Rebase webkitgtk-typelib-sharelib-link.patch.
- Add pkgconfig(gnutls) BuildRequires: New dependency.
* Tue Sep  6 2016 fezhang@suse.com
- Rebase webkitgtk-disable-gcc-version-checks.patch for 2.12.5
* Mon Sep  5 2016 zaitor@opensuse.org
- Update to version 2.12.5:
  + Fix a regression introduced in 2.12.4 that caused a hang in the
    network process after a load failure.
  + Fix several crashes and rendering issues.
* Thu Aug 25 2016 sreeves@suse.com
- Rebase webkitgtk-disable-gcc-version-checks.patch for 2.12.4
* Thu Aug 25 2016 zaitor@opensuse.org
- Update to version 2.12.4:
  + Security fixes: CVE-2016-4622, CVE-2016-4624, CVE-2016-4591,
    CVE-2016-4590.
  + Fix performance in accelerated compositing mode with the
    modesetting intel driver and DRI3 enabled.
  + Reduce the amount of file descriptors that the Web Process
    keeps open.
  + Fix Web Process deadlocks when loading HLS videos.
  + Make CSS and SVG animations run at 60fps.
  + Make meter elements accessible.
  + Improve accessibility name and description of elements to make
    it more compatible with W3C specs and fix several bugs in which
    the accessible name of objects was missing or broken.
  + Fix a crash when running windowed plugins under Wayland.
  + Fix a crash at process exit under Wayland.
  + Fix several crashes and rendering issues.
  + Updated translations.
- Update _constraints memory requirements.
* Mon Jun 20 2016 fcrozat@suse.com
- Refresh webkitgtk-disable-gcc-version-checks.patch for latest
  version.
* Fri Jun 17 2016 zaitor@opensuse.org
- Update to version 2.12.3:
  + Security fixes: CVE-2016-1857, CVE-2016-1856.
  + Improved the detection of supported MIME types supported by the
    media player.
  + Fix web process crash when playing adaptive streaming media.
  + Change the volume while thumb slider is dragged, not only when
    released.
  + Fix leaked thread in network process.
  + Fix several crashes and rendering issues.
  + Updated translations.
* Tue Jun  7 2016 dimstar@opensuse.org
- Also apply webkitgtk-disable-gcc-version-checks.patch on Leap
  and use GCC 4.8.
- Change condition to pass -DENABLE_DATABASE_PROCESS=OFF,
  - DENABLE_INDEXED_DATABASE=OFF and -DENABLE_FTL_JIT=OFF to cmake:
  newly on all SLE12 based systems (incl. Leap).
* Fri May 27 2016 idonmez@suse.com
- Update to GNOME 3.20.2 FATE#318572
* Thu May  5 2016 ro@suse.de
- add -DUSE_SYSTEM_MALLOC=ON as in factory on ppc/s390
* Wed May  4 2016 ro@suse.de
- handle s390 like s390x to fix build
* Mon May  2 2016 fcrozat@suse.com
- Refresh webkitgtk-disable-gcc-version-checks.patch for latest
  version.
* Thu Apr 28 2016 zaitor@opensuse.org
- Update to version 2.12.2:
  + Fix rendering of scrollbars with GTK themes using stepper
    buttons.
  + Fix compatibility issue with 2.12.1 regarding local storage
    access from file URLs.
  + Make menu list buttons use the text color from the theme.
  + Do not show resize grip in non-resizable text fields.
  + Fix accessibility events causing Orca to echo key presses
    instead of speaking the inserted characters in password fields.
  + Fix an off by one error in hyphenation.
  + Fix several crashes and rendering issues.
  + Fix the build with libjpeg v9.
  + Updated translations.
* Mon Apr 25 2016 zaitor@opensuse.org
- Drop pkgconfig(gtk+-2.0) BuildRequires and pass
  - DENABLE_PLUGIN_PROCESS_GTK2=OFF to configure. We do no longer
  ship the flash-plugin in openSUSE, and it were the last consumer
  of this functionality. This also have the added bonus of freeing
  zenity and dependant packages of gtk2 dependencies.
* Fri Apr 15 2016 zaitor@opensuse.org
- Update to version 2.12.1:
  + Fix spotify player.
  + Improve themed control elements rendering to better match GTK+
    widgets.
  + Make remote web inspector work again.
  + Fix several crashes and rendering issues.
  + Fix several memory leaks.
  + Fix the build in Linux / PowerPC.
  + Fix detection of S390X and PPC64 architectures.
  + Fix the build in glibc-based BSD systems.
  + Updated translations.
- Add -DUSE_SYSTEM_MALLOC=ON  to configure for ppc ppc64 ppc64le
  and s390x, needed now for build to complete.
* Wed Mar 23 2016 fcrozat@suse.com
- Refresh webkitgtk-disable-gcc-version-checks.patch for latest
  version.
* Tue Mar 22 2016 zaitor@opensuse.org
- Update to version 2.12.0:
  + Enable GSS-Negotiate support when available in libsoup.
  + Fix overlay scrollbar indicator position.
  + Fix smooth scrolling behavior that was not fixed in all cases
    in 2.11.92.
  + Fix the build with newer versions of GCC and clang.
* Thu Mar 17 2016 fcrozat@suse.com
- Update webkitgtk-disable-gcc-version-checks.patch (partially
  merged).
* Wed Mar 16 2016 zaitor@opensuse.org
- Update to version 2.11.92:
  + Revert the patch to limit the number of tiles according to the
    visible area introduced in 2.11.90, because it caused rendering
    issues in several popular websites.
  + Fix scrollbars rendering again with GTK+ >= 3.19.11.
  + Fix rendering of slider input elements.
  + Fix rendering artifacts when using a web view background color.
  + Make webkit_web_context_clear_cache() work again.
  + Fix smooth scrolling behavior that was changed by mistake.
  + Don’t force ENABLE_INTROSPECTION=OFF on Mac.
  + Install WebProcess and NetworkProcess on OSX when not building
    the Mac port.
* Wed Mar  2 2016 fcrozat@suse.com
- Update webkitgtk-disable-gcc-version-checks.patch to properly
  disable terminateDatabaseProcess method when it is disabled at
  compilation time.
* Wed Mar  2 2016 fcrozat@suse.com
- Refresh webkitgtk-disable-gcc-version-checks.patch for latest
  webkitgtk.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 2.11.91:
  + Do not show stale contents after session restore.
  + Fix flickering and rendering artifacts when entering
    accelerated compositing mode before the web view is realized.
  + Fix several rendering issues and crashes.
  + Fix build with FTL enabled in FreeBSD.
  + Updated translations.
* Tue Feb 23 2016 fcrozat@suse.com
- Update webkitgtk-disable-gcc-version-checks.patch to fix building
  with gcc 4.8 (fix from Mike Gorse).
* Fri Feb 19 2016 dimstar@opensuse.org
- Update to version 2.11.90:
  + Switch to use overlay scrollbars like all other GTK+ widgets
    and ensure the behavior is consistent with GTK+ too.
  + Limit the number of tiles according to the visible area. This
    was causing a huge memory consumption with some websites.
  + Fix toggle buttons rendering with GTK+ 3.19.
  + Fix HTTP authentication dialog rendering when accelerated
    compositing mode is enabled.
  + Use G_TYPE_ERROR instead of G_TYPE_POINTER for GError
    parameters of signals.
  + Fix several memory leaks.
- Rebase webkitgtk-disable-gcc-version-checks.patch.
* Tue Feb 16 2016 fcrozat@suse.com
- Do not use binutils-gold on s390x and try to minimize memory used
  there at linking time.
- Ensure JIT is also disabled on s390x.
* Mon Feb 15 2016 fcrozat@suse.com
- Refresh webkitgtk-disable-gcc-version-checks.patch for latest
  webkitgtk.
* Fri Feb 12 2016 zaitor@opensuse.org
- Update to version 2.11.5:
  + Switch FTL to use B3 backend instead of LLVM.
  + Add support for windowless NPAPI plugins with no UI in non X11
    platforms.
  + Fix a deadlock in the Web Process when JavaScript garbage
    collector was running for a web worker thread that made google
    maps to hang.
  + Fix a Web Process crash when quickly attempting many DnD
    operations.
  + Fix scrollbars rendering with older versions of GTK+.
  + Fix a crash when creating a WebKitWebView without providing a
    WebKitWebContext.
- Drop llvm-devel BuildRequires as upstream now supports B3 instead
  of LLVM.
* Thu Feb 11 2016 fcrozat@suse.com
- Refresh webkitgtk-disable-gcc-version-checks.patch for latest
  webkitgtk.
* Thu Feb  4 2016 zaitor@opensuse.org
- Update to version 2.11.4:
  + Prefer to link to LLVM shared libraries when building with FTL
    enabled.
  + Fix runtime errors when serializing/deserializing session
    state.
  + Fix critical warnings when loading a URL after a session
    restore.
  + Fix the build with GTK+ < 3.14.
  + Fix the build with video support disabled.
- Drop webkitgtk-llvm-shared-libs.patch: Fixed upstream.
* Wed Feb  3 2016 fcrozat@suse.com
- Refresh webkitgtk-disable-gcc-version-checks.patch for latest
  webkitgtk.
* Wed Feb  3 2016 mcatanzaro@igalia.com
- Update to version 2.11.3:
  - NetworkProcess is now used unconditionally. The shared
    secondary process model is now the same as using the multiple
    process model and setting a process limit of 1.
  - Disable DNS prefetch when a proxy is configured.
  - Reduce the maximum simultaneous network connections to match
    other browsers.
  - Extend notifications API to notify WebKit when a notification
    is clicked by the user.
  - Add new API to save and restore a WebView session.
  - Add Web Extensions API to be notified about console messages.
  - Add WebKitURIRequest API to get the HTTP method.
  - Add API to handle beforeunload events.
  - Make WebKitWebView always propagate motion-notify-event signal.
  - Add a way to force accelerating compositing mode at runtime
    using an environment variable.
  - Fix input elements and scrollbars rendering with GTK+ 3.19.
  - Fix a crash in the UI process when the WebView is destroyed
    while the screensaver DBus proxy is being created.
  - Fix a WebProcess crash when loading large contents with
    custom URI schemes API.
  - Fix UI process crashes related to not having a main resource
    response when the load is committed for pages restored from
    the history cache.
- Reenable JIT on SLE, except for the fourth tier (FTL) which
  requires LLVM 3.7.
- Add webkitgtk-llvm-shared-libs.patch to replace llvm-config
  wrapper script.
* Wed Feb  3 2016 fcrozat@suse.com
- Disable database support on SLE, which is requiring gcc >= 4.9:
  Add patch webkitgtk-disable-gcc-version-checks.patch to allow
  building with gcc 4.8, change BuildRequires to gcc-c++ /
  libedit-devel on SLE, instead of gcc-c++ >= 4.9 and llvm-devel,
  disable database and indexed database on SLE and disable JIT
  support on all platforms on SLE, which requires llvm >= 3.7.
* Wed Feb  3 2016 mcatanzaro@igalia.com
- Miscellaneous cleanups.
- Stop setting ENABLE_YARR_JIT=OFF on secondary arches. Nowadays
  ENABLE_YARR_JIT is a private option, and setting ENABLE_JIT=OFF
  is sufficient to do the right thing.
* Wed Feb  3 2016 dimstar@opensuse.org
- Fix build:
  + Add llvm-devel and ncurses-devel BuildRequires.
  + Inject a llvm-config wrapper script into ~/bin, which replaces
    the original's output of static libs with dynamic shared
    objects. This is supposedly going to be corrected with
    LLVM 3.8.
* Wed Feb  3 2016 zaitor@opensuse.org
- Update to version 2.11.2:
  + Enable FTL by default in JavaScriptCore for x86_64.
  + Improved media backend performance by better handling glib main
    loop sources.
  + Fix rendering of lines when using solid colors.
  + Fix web process crashes due to BadDrawable X errors in
    accelerated compositing mode.
  + Updated translations.
* Wed Feb  3 2016 zaitor@opensuse.org
- Update to version 2.10.7:
  + Fix the build with GTK+ < 3.16.
* Thu Jan 28 2016 zaitor@opensuse.org
- Update to version 2.10.6:
  + Fix a deadlock in the Web Process when JavaScript garbage
    collector was running for a web worker thread that made google
    maps to hang.
  + Fix media controls displaying without controls attribute.
  + Fix a Web Process crash when quickly attempting many DnD
    operations.
* Mon Nov 23 2015 zaitor@opensuse.org
- Add binutils-gold BuildRequires: Use the gold linker for build
  and remove --reduce-memory-overheads from RPMOPT flags since
  gold-linker does not know it.
* Wed Nov 11 2015 zaitor@opensuse.org
- Update to version 2.11.1:
  + Improved general performance by better handling glib main loop
    sources.
  + Add autocleanups support to GObjects exposed in public API.
  + Upload the accelerated canvas as a texture by copying via GPU
    directly.
  + Popup menus no longer use a nested main loop.
* Wed Nov 11 2015 zaitor@opensuse.org
- Update to version 2.10.4:
  + Fixed dashed and dotted border painting.
  + Properly cancel navigation policy checks.
  + Several crashes fixed when running editor commands.
  + Fix several crashes due to assertions in Debug builds.
  + Fix the build on Mac OSX and bring back the Quartz target.
  + Fix the build on glibc-based BSD systems.
* Mon Oct 26 2015 zaitor@opensuse.org
- Update to version 2.10.3:
  + Fix graphics artifacts when entering/leaving Accelerated
    Compositing mode.
  + Honour 'forwards' fill-mode in Multiple-keyframe and delayed
    instantaneous animations.
  + Fix runtime warning when the inspector is closed.
  + Fix the build with GTK+2 plugin process disabled.
  + Gracefully handle errors when sending/receiving IPC messages
    data on connection close.
  + Fix several crashes and rendering issues.
* Thu Oct 15 2015 zaitor@opensuse.org
- Update to version 2.10.2:
  + Fix a regression introduced in 2.10.1 that disabled accelerated
    compositing.
  + Fix build with cmake 3.4.
* Wed Oct 14 2015 zaitor@opensuse.org
- Update to version 2.10.1:
  + Fix rendering of accelerated content in HiDPI screens.
  + Fix several media controls rendering issues.
  + Fix rendering of progress element with recent versions of GTK+.
  + Add and update some web inspector icons.
  + Correctly handle websites sending an invalid auth header.
  + Fix a crash when creating the UI process backing store in
    Wayland.
  + Fix the build with spellchecker disabled.
  + Fix the build with touch events disabled.
  + Fix the build with OpenGL disabled.
  + Several build fixes on Mac OSX.
  + Fix several crashes and rendering issues.
* Mon Sep 21 2015 zaitor@opensuse.org
- Update to version 2.10.0:
  + New HTTP disk cache for the Network Process.
  + IndexedDB support.
  + New Web Inspector UI.
  + Automatic ScreenServer inhibition when playing fullscreen
    videos.
  + Improved font matching algorithm.
  + Initial Editor API.
  + Performance improvements.
* Wed Sep 16 2015 zaitor@opensuse.org
- Update to version 2.9.92:
  + Data URLs are now decoded in the Web Process instead of the
    Network Process.
  + Fix Web Process crash recovery.
  + Fix a crash when sqlite3_initialize() is called from multiple
    threads.
  + Fix the volume bar in media controls.
  + Fix JavaScriptCore build with GCC 5.
  + Fix the build when accelerated 2D canvas is enabled but cairo
    was built without GLX.
  + Fix everal memory leaks.
  + Updated translations.
- Drop webkitgtk-gcc5-buildfix.patch: Fixed upstream.
* Wed Aug 26 2015 zaitor@opensuse.org
- Update to version 2.9.91:
  + Fix performance regression introduced in previous release when
    scaling images.
  + Fix runtime critical warning when there are missing media
    plugins.
  + Fix the build on systems with GTK+ compiled with an old version
    of wayland.
* Sun Aug 16 2015 zaitor@opensuse.org
- Update to version 2.9.90:
  + Add API to request permission before showing PackageKit codec
    installation notifications.
  + Fix a crash closing a page when a context menu is open.
  + Fix DNS prefetch when using the network process.
  + Improve image quality when using newer versions of
    cairo/pixman.
  + Fix a crash when the web view is destroyed while the
    screensaver DBus proxy is being created.
* Tue Aug 11 2015 zaitor@opensuse.org
- Update to version 2.9.5:
  + Add API to set the maximum number of web processes per
    WebKitWebContext.
  + Add API to allow executing editing commands that require an
    argument.
  + Prevent clipboard contents from being lost when web process
    finishes.
  + Always allow font matching for strong aliases.
  + Move GStreamer missing plugins installer to the UI process.
  + Fix empty space in popup menus when first item is selected.
  + Fix a crash when SoupSession is destroyed in exit handler.
  + Disable NPAPI plugins when running on Wayland.
  + Updated translations.
* Thu Aug  6 2015 zaitor@opensuse.org
- Update to version 2.9.4:
  + Fix the window size reported when the web view isn't realized
    yet. This fixes the layout of some websites when opening new
    tabs in the browser and anchor links when opened in new tabs
    too.
  + Add API to be notified about editor state changes.
  + Add selection-changed signal to the Web Extensions API.
  + Add initial WebKitWebsiteDataManager API for process
    configuration options.
  + Make WebSQL work by using a default quota instead of always
    failing in openDatabase with DOM Exception 18.
  + Correctly restore accelerated compositing after a WebProcess
    crash.
  + Only enable the input methods filter when there's an editable
    element focused.
  + Fix a crash on memory allocation using bmalloc on 32bit
    systems.
  + Allow to build with X11 and Wayland targets at the same time.
  + Fix a crash when spell checker returns no guesses.
  + Update and optimize some of the web inspector icons.
  + Updated translations.
* Thu Aug  6 2015 zaitor@opensuse.org
- Update to version 2.9.3:
  + Inhibit screen saver when playing full screen video.
  + Fix DOCUMENT_VIEWER cache model to actually disable the memory
    cache.
  + Fix a regression that prevented the WebKitWebView::context-menu
    signal from being emitted.
  + Update web inspector icon so Rendering Frames timeline
    distinguish between layout and painting.
  + Ensure fragment identifier part of URI is not removed for
    custom URI scheme requests.
  + Improve performance of keyboard events handling.
  + Expose element tag name as an object attribute to
    accessibility.
  + Fix the build with Wayland target enabled.
* Thu Aug  6 2015 zaitor@opensuse.org
- Update to version 2.9.2:
  + Add IndexedDB support using a dedicated database process.
  + Add construct property to WebKitWebContext to set the IndexedDB
    database directory.
  + Add allow-file-access-from-file-urls to WebKitSettings.
  + Improve network process disk cache performance by mapping
    cached resources in the web process instead of sending the
    resources data via IPC.
  + Prevent WorkQueue objects from being leaked and ensure its
    worker thread always exits.
  + webkit_dom_html_element_get_children() has been deprecated in
    favor of webkit_dom_element_get_children() to match the DOM
    spec.
  + ARIA menu items no longer have anonymous block children.
  + Map pre element to ATK_ROLE_SECTION instead of ATK_ROLE_PANEL.
  + Always include rows in the tree of accessible tables.
  + Fix the build with Netscape plugins disabled.
  + Fix XPixmaps leaked by GLContext when using EGL on X11.
  + Updated translations.
* Thu Aug  6 2015 zaitor@opensuse.org
- Update to version 2.9.1:
  + New disk cache implementation when using the network process.
  + Web inspector UI has been redesigned.
  + Add support for automatic hyphenation using libhyphen when it's
    available.
  + Fix network redirection to a non HTTP destination.
- Add hyphen-devel BuildRequires: New dependency.
* Thu Aug  6 2015 zaitor@opensuse.org
- Update to version 2.8.5:
  + Fix the window size reported when the web view isn't realized
    yet. This fixes the layout of some websites when opening new
    tabs in the browser and anchor links when opened in new tabs
    too.
  + Prevent clipboard contents from being lost when web process
    finishes.
  + Always allow font matching for strong aliases.
  + Move GStreamer missing plugins installer to the UI process.
  + Fix a crash when spell checker returns no guesses.
  + Fix a crash when SoupSession is destroyed in exit handler.
  + Fix a crash closing a page when default context menu is open.
  + Several crashes and rendering issues fixed.
  + Updated translations.
* Tue Aug  4 2015 zaitor@opensuse.org
- Modify _constraints file for armv6l/armv7l arches to sizes so low
  that in practice it's disabled.
* Thu Jul  9 2015 zaitor@opensuse.org
- Update to version 2.8.4:
  + Make WebSQL work by using a default quota instead of always
    failing in openDatabase with DOM Exception 18.
  + Improve detection and usage of GL/GLES/EGL libraries.
  + Fix a crash on memory allocation using bmalloc on 32bit
    systems.
  + Fix DOCUMENT_VIEWER cache model to actually disable the memory
    cache.
  + Fix a WebProcess crash after too many redirect error when
    there's an active NPAPI plugin.
  + Fix a WebProcess crash when gtk-font-name setting is empty.
  + Ensure Math.abs() doesn't return negative.
  + Correctly restore accelerated compositing after a WebProcess
    crash.
  + Respect X-Frame-Options headers when loading from application
    cache.
  + Several crashes and rendering issues fixed.
  + Fix the MIPS N64 detection.
  + Fix several memory leaks.
  + Updated translations.
* Thu May 21 2015 zaitor@opensuse.org
- Update to version 2.8.3:
  + Fixed a regression introduced in 2.8.2 that broke downloads
    when using the network process.
  + Fix the build with Netscape plugins disabled.
  + Fix XPixamps leaked by GLContext when using EGL on X11.
- Changes from version 2.8.2:
  + Fix network redirection to a non HTTP destination.
  - Use a webkit subdirectory for the disk cache to avoid conflicts
    with other files in the cache directory when the disk cache is
    cleaned up.
  - Do not preserve the Origin header on on cross-origin redirects.
  - Prevent WorkQueue objects from being leaked and ensure its
    worker thread always exits.
* Tue Apr 14 2015 zaitor@opensuse.org
- Update to version 2.8.1:
  + Handle keep-alive connections in GStreamer HTTP source element.
  + Fix a crash in DOMObjectCache when a wrapped object owned by.
    the cache is unreffed by the user.
  + Fix rendering of drag and drop icon.
  + Fix the build with REDIRECTED_XCOMPOSITE_WINDOW disabled in X11
    platform.
  + Fix the build with Wayland target enabled.
  + Fix the build for HPPA.
- Add webkitgtk-gcc5-buildfix.patch: Fix build with gcc5.
* Thu Apr  9 2015 mcatanzaro@igalia.com
- Add BuildRequires pkgconfig(libnotify) to build with support for
  HTML5 notifications (bnc#926482).
* Thu Mar 26 2015 dimstar@opensuse.org
- Change webkit2gtk-4_0-injected-bundles Recommends to Requires:
  apps fail to load webkit if the bunldes are not available.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 2.8.0:
  + Initial gestures support.
  + HTML5 notifications.
  + User script messages.
  + HTML5 color input.
  + APNG support.
  + Performance improvements.
  + Playing audio notification signal.
  + Web view background colors.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 2.7.92:
  + Add APNG support.
  + Disable RC4 support in networking backend.
  + Add a configure option to build with OpenGL ES 2.
  + Add an option to enable MiniBrowser for non developer builds
    and always install it.
  + Check TLS errors as soon as they are set in the SoupMessage to
    prevent any data from being sent to the server in case of
    invalid certificate.
  + Make WebKitWebView always hold a reference on WebKitWebContext
    now that it’s possible to create new web contexts.
  + Fix a crash when entering accelerated compositing mode before
    the WebView is realized.
  + Fix some transfer annotations used in GObject DOM bindings.
  + Fix GObject DOM objects leaked when the web view contents are
    updated.
  + Fix a crash viewing http://www.last.fm/.
  + Fix an infinite loop in ARM Linux when parallel GC is enabled
    it again.
  + Fix the build with older versions of GStreamer.
  + Fix the build when NEON_INTRINSICS is enabled.
  + Fix the build with video enabled but WebAudio disabled.
- Changes from version 2.7.91:
  + Enable concurrent JIT.
  + Add support for ARIA 1.1 ‘switch’ and ‘searchbox’ roles.
  + Fix synchronous loads when maximum connection limits are
    reached.
  + Fix web timing calculations when loading resources from the
    disk cache.
  + Fix a crash when loading a local file with
    webkit_web_view_load_alternate_html.
  + Fix a WebProcess crash when entering accelerating compositing
    mode before the WebView is realized.
  + Improve the appearance of fonts loaded via @font-face.
  + Fix undefined symbol issue when loading web extensions.
  + Build bmalloc as a static library.
  + Fix the build with CMake 3.2.
  + Fix the C-Loop LLInt build.
  + Updated translations.
- Drop webkitgtk-bmalloc-as-static.patch: fixed upstream.
* Thu Feb 26 2015 dimstar@opensuse.org
- Add webkitgtk-bmalloc-as-static.patch: Build libbmalloc as static
  library. Only webkitgtk depends on it.
* Thu Feb 19 2015 dimstar@opensuse.org
- Update to version 2.7.90:
  + Use the new memory allocator bmalloc instead of TCMalloc which
    drastically improves the overall performance.
  + Remove WebKitWebView::close-notification signal and add
    WebKitNotification::closed instead.
  + Implement support for new AtkRole types for MathML.
  + Add support for input color type.
  + Add API to allow overriding the default color chooser
    implementation.
  + Resize the accelerating compositing window to a minimum size
    again after leaving accelerated compositing mode to save
    memory.
  + Ensure WebKitFrame objects are released when the frame is
    destroyed.
  + Clear the GObject DOM bindings internal cache when frames are
    destroyed.
  + Implement page overlays to bring back the inspector element
    highlighting.
  + Fix startup runtime critical warnings when using the network
    process.
  + Fix the build with recent versions of GLib that have
    GMutexLocker.
  + Fix the gtk-doc generation to appear in DevHelp.
* Fri Jan 23 2015 zaitor@opensuse.org
- Update to version 2.7.4:
  + Add API to change the WebKitWebView background color.
  + Add an option to create WebKitWebView snapshots with
    transparent background.
  + Add API to make the WebKitWebView editable.
  + Add is-playing-audio property to WebKitWebView.
  + Do not resize the accelerating compositing window to the web
    size until accelerated compositing mode is activated.
* Fri Jan 23 2015 zaitor@opensuse.org
- Update to version 2.7.3:
  + Add API to support HTML5 notifications.
  + Add UserMedia Permission Request API.
  + GObject DOM bindings API now correctly returns NULL intead of
    empty strings to be able to differentiate between not present
    and present but empty.
  + Add support for text-decoration-skip.
  + Improve the HTTP authentication dialog.
  + Expose the ID attribute of Meter and Option elements to
    accessibility.
  + Use latin1 instead of UTF-8 for HTTP header values.
  + Update NavigationItemProbes inspector icon.
  + Add video/mp2t as alternative mimetype for MPEG TS.
  + Add application/x-mpegurl and video/flv to the list of
    supported mimetypes.
  + Add SCHEDULING query support to HTTP media source element.
  + Fix deadlock when shutting down AudioDestination.
  + Updated translations.
- Changes from version 2.7.2:
  + Fix SSL connection issues with some websites after the POODLE
    vulnerability fix.
  + Add API to handle user script messages.
  + Add context menu API to Web Process Extensions.
  + Add API to create a WebKitWebContext.
  + Add API to override the default local storage directory.
  + Add WebKitWebResource::failed-with-tls-errors signal to notify
    about load failures due to TLS errors also in sub-resources.
  + Fix several crashes in accessibility implementation.
  + Fix XMLHttpRequest with a timeout when using the network
    process.
  + Fix XMLHttpRequest with cookies disabled when using the network
    process.
  + Fix a crash in the network process when a synchronous load
    redirects to a new url in a different security origin.
  + Fix a crash in TextureMapper when video resolution changes.
  + Correctly report the memory used by the media player to the
    garbage collector to make sure it’s freed when the video
    element is removed from the DOM.
  + Fix documentation of webkit_print_operation_get_page_setup().
* Fri Jan 23 2015 zaitor@opensuse.org
- Update to version 2.6.5:
  + Fix issue that caused some text to be inserted when trying to
    delete a word from the Twitter message box.
  + GObject DOM bindings API now correctly returns NULL intead of
    empty strings to be able to differentiate between not present
    and present but empty.
  + Do not resize the accelerating compositing window to the web
    size until accelerated compositing mode is activated.
  + Use latin1 instead of UTF-8 for HTTP header values.
  + Add SCHEDULING query support to HTTP media source element.
  + Add application/x-mpegurl and video/flv to the list of
    supported mimetypes.
  + Update NavigationItemProbes inspector icon.
  + Fix the build with recent GStreamer.
  + Fix the build on FreeBSD.
  + Fix build on OS X.
  + Fix the build on powerpc 32 bits.
  + Fixed several crashes in WebCore and JavaScriptCore.
  + Updated translations.
- Drop webkitgtk-libatomic.patch: Fixed upstream.
* Tue Jan 13 2015 schwab@suse.de
- Add webkitgtk-libatomic.patch: Check if libatomic is needed in
  order to use std::atomic; fixes build on ppc.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 2.6.4:
  + Fix SSL connection issues with some websites after the POODLE
    vulnerability fix.
  + Fix several crashes in accessibility implementation.
  + Fix XMLHttpRequest with a timeout when using the network
    process.
  + Fix XMLHttpRequest with cookies disabled when using the network
    process.
  + Fix a crash in the network process when a synchronous load
    redirects to a new url in a different security origin.
  + Fix documentation of webkit_print_operation_get_page_setup().
  + Allow to build with GObject introspection disabled.
  + Fix the remote inspector when settings don't change after page
    initialization.
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 2.6.3:
  + Fix a crash when loading flash plugins.
  + Correctly report the memory used by the media player to the
    garbage collector to make sure it's freed when the video
    element is removed from the DOM.
  + Fix a crash in TextureMapper when video resolution changes.
  + Ensure that CSS-generated text content is exposed to assistive
    technologies.
  + Enable CSS_IMAGE_SET on production builds to fix some icons
    that are not rendered in the web inspector.
  + Fix the build on FreeBSD and GNU Hurd.
  + Fix the build with video disabled.
* Sat Oct 25 2014 dimstar@opensuse.org
- Update to version 2.6.2:
  + SSLv3 is now disabled to protect us against POODLE
    vulnerability.
  + TLS errors are no longer ignored by default.
  + Fix the remote web inspector.
  + Fix rendering of buttons, selections and lists with recent GTK+
    versions.
  + Improve performance of timers scheduled after a delay in
    microseconds.
  + Fix WebKitSettings:enable-smooth-scrolling to actually enable
    smooth scrolling.
  + Fix the build with drag and drop support disabled.
* Tue Oct 14 2014 dimstar@opensuse.org
- Update to version 2.6.1:
  + Ensure WebKitWebView:is-loading is TRUE right after a new load
    starts.
  + Fix a crash in the plugin process with some windowed flash
    plugins.
  + Allow to dock the inspector again once undocked when building
    with GTK+ >= 3.10.
  + TLS errors now take precedence over the HTTP authentication
    dialog.
  + Do not shrink on-disk cache to its default size on startup.
  + Improve the proportion and visibility of some web inspector
    icons.
  + Fix GTK+2 plugins not working after being updated.
  + Don’t include full path names in WebKitEnumTypes.h to ensure
    the generated headers are always identical.
  + Updated transations.
* Mon Oct 13 2014 dvaleev@suse.com
- Disable JIT on Power architectures
  (-DEANBLE_JIT=OFF -DENABLE_YARR_JIT=0)
* Thu Sep 25 2014 dimstar@opensuse.org
- Update to version 2.6.0:
  + Make vimeo videos work again with the GStreamer media backend.
  + Add more free icons for the web inspector.
  + Fix a WebSocket crash when a connection is closed from server
    side.
  + Fixed a memory leak in JavaScriptCore.
  + Fix the build with video support disabled.
  + Fix CLoop on the 32-bit Big-Endians.
  + Updated translations.
* Sun Sep 21 2014 dimstar@opensuse.org
- Update to version 2.5.90:
  + Use free icons for the web inspector.
  + Change WebKitWebView::load-failed-with-tls-errors signal to
    pass the failing URI as signal argument instead of the host.
  + Add new API to allow overwrite existing files when downloading
    a file.
  + Add webkit_uri_response_get_http_headers() API.
  + Improve the UI of the HTTP authentication dialog.
  + Fix a crash when navigating away from a web page containing an
    ogg video.
  + Fix race condition when downloading a file due to the
    intermediate temporary file.
  + Fix toggle buttons rendering with recent GTK+ versions.
  + Fix selection rendering when unfocused with recent GTK+
    versions.
  + Mak e the GStreamer media backend not send the transferMode
    HTTP header.
- Setup environment to prefer GOLD linker (softlink
  /usr/bin/ld.gold to ~/bin/ld).
* Mon Sep  8 2014 dimstar@opensuse.org
- Pass -DCMAKE_{EXE,MODULE,SHARED}_LINKER_FLAGS="-Wl,--as-needed
  - Wl,-z,now" to cmake call: cmake changed the default to not
  accept libraries to have undefined symbols (-Wl,--no-undefined).
  In this case though, it is understood and expected, so we remove
  - -no-undefined from the FLAGS.
* Wed Aug 13 2014 dimstar@opensuse.org
- Initial package, version 2.5.3; based on webkitgtk3.spec.
